"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtOpenGL import *


class QOpenGLFunctions_4_1_Core(QAbstractOpenGLFunctions):
    """
    https://doc.qt.io/qt-6/qopenglfunctions-4-1-core.html

    **Detailed Description**

    This class is a wrapper for functions from OpenGL 4.1 core profile. See
    reference pages on **opengl.org**  for function documentation.

    **See also** **QAbstractOpenGLFunctions** .
    """

    def __init__(self) -> None:
        ...

    def glReleaseShaderCompiler(self) -> None:
        ...

    def glDepthRangef(self, n: float, f: float) -> None:
        ...

    def glClearDepthf(self, dd: float) -> None:
        ...

    def glProgramParameteri(self, program: int, pname: int, value: int) -> None:
        ...

    def glUseProgramStages(self, pipeline: int, stages: int, program: int) -> None:
        ...

    def glActiveShaderProgram(self, pipeline: int, program: int) -> None:
        ...

    def glBindProgramPipeline(self, pipeline: int) -> None:
        ...

    def glIsProgramPipeline(self, pipeline: int) -> int:
        ...

    def glProgramUniform1i(self, program: int, location: int, v0: int) -> None:
        ...

    def glProgramUniform1f(self, program: int, location: int, v0: float) -> None:
        ...

    def glProgramUniform1d(self, program: int, location: int, v0: float) -> None:
        ...

    def glProgramUniform1ui(self, program: int, location: int, v0: int) -> None:
        ...

    def glProgramUniform2i(self, program: int, location: int, v0: int, v1: int) -> None:
        ...

    def glProgramUniform2f(
        self, program: int, location: int, v0: float, v1: float
    ) -> None:
        ...

    def glProgramUniform2d(
        self, program: int, location: int, v0: float, v1: float
    ) -> None:
        ...

    def glProgramUniform2ui(
        self, program: int, location: int, v0: int, v1: int
    ) -> None:
        ...

    def glProgramUniform3i(
        self, program: int, location: int, v0: int, v1: int, v2: int
    ) -> None:
        ...

    def glProgramUniform3f(
        self, program: int, location: int, v0: float, v1: float, v2: float
    ) -> None:
        ...

    def glProgramUniform3d(
        self, program: int, location: int, v0: float, v1: float, v2: float
    ) -> None:
        ...

    def glProgramUniform3ui(
        self, program: int, location: int, v0: int, v1: int, v2: int
    ) -> None:
        ...

    def glProgramUniform4i(
        self, program: int, location: int, v0: int, v1: int, v2: int, v3: int
    ) -> None:
        ...

    def glProgramUniform4f(
        self, program: int, location: int, v0: float, v1: float, v2: float, v3: float
    ) -> None:
        ...

    def glProgramUniform4d(
        self, program: int, location: int, v0: float, v1: float, v2: float, v3: float
    ) -> None:
        ...

    def glProgramUniform4ui(
        self, program: int, location: int, v0: int, v1: int, v2: int, v3: int
    ) -> None:
        ...

    def glValidateProgramPipeline(self, pipeline: int) -> None:
        ...

    def glVertexAttribL1d(self, index: int, x: float) -> None:
        ...

    def glVertexAttribL2d(self, index: int, x: float, y: float) -> None:
        ...

    def glVertexAttribL3d(self, index: int, x: float, y: float, z: float) -> None:
        ...

    def glVertexAttribL4d(
        self, index: int, x: float, y: float, z: float, w: float
    ) -> None:
        ...

    def glViewportIndexedf(
        self, index: int, x: float, y: float, w: float, h: float
    ) -> None:
        ...

    def glScissorIndexed(
        self, index: int, left: int, bottom: int, width: int, height: int
    ) -> None:
        ...

    def glDepthRangeIndexed(self, index: int, n: float, f: float) -> None:
        ...

    def glMinSampleShading(self, value: float) -> None:
        ...

    def glBlendEquationi(self, buf: int, mode: int) -> None:
        ...

    def glBlendEquationSeparatei(self, buf: int, modeRGB: int, modeAlpha: int) -> None:
        ...

    def glBlendFunci(self, buf: int, src: int, dst: int) -> None:
        ...

    def glBlendFuncSeparatei(
        self, buf: int, srcRGB: int, dstRGB: int, srcAlpha: int, dstAlpha: int
    ) -> None:
        ...

    def glUniform1d(self, location: int, x: float) -> None:
        ...

    def glUniform2d(self, location: int, x: float, y: float) -> None:
        ...

    def glUniform3d(self, location: int, x: float, y: float, z: float) -> None:
        ...

    def glUniform4d(
        self, location: int, x: float, y: float, z: float, w: float
    ) -> None:
        ...

    def glPatchParameteri(self, pname: int, value: int) -> None:
        ...

    def glBindTransformFeedback(self, target: int, id: int) -> None:
        ...

    def glIsTransformFeedback(self, id: int) -> int:
        ...

    def glPauseTransformFeedback(self) -> None:
        ...

    def glResumeTransformFeedback(self) -> None:
        ...

    def glDrawTransformFeedback(self, mode: int, id: int) -> None:
        ...

    def glDrawTransformFeedbackStream(self, mode: int, id: int, stream: int) -> None:
        ...

    def glBeginQueryIndexed(self, target: int, index: int, id: int) -> None:
        ...

    def glEndQueryIndexed(self, target: int, index: int) -> None:
        ...

    def glVertexAttribDivisor(self, index: int, divisor: int) -> None:
        ...

    def glIsSampler(self, sampler: int) -> int:
        ...

    def glBindSampler(self, unit: int, sampler: int) -> None:
        ...

    def glSamplerParameteri(self, sampler: int, pname: int, param: int) -> None:
        ...

    def glSamplerParameterf(self, sampler: int, pname: int, param: float) -> None:
        ...

    def glQueryCounter(self, id: int, target: int) -> None:
        ...

    def glVertexAttribP1ui(
        self, index: int, type: int, normalized: int, value: int
    ) -> None:
        ...

    def glVertexAttribP2ui(
        self, index: int, type: int, normalized: int, value: int
    ) -> None:
        ...

    def glVertexAttribP3ui(
        self, index: int, type: int, normalized: int, value: int
    ) -> None:
        ...

    def glVertexAttribP4ui(
        self, index: int, type: int, normalized: int, value: int
    ) -> None:
        ...

    def glFramebufferTexture(
        self, target: int, attachment: int, texture: int, level: int
    ) -> None:
        ...

    def glProvokingVertex(self, mode: int) -> None:
        ...

    def glTexImage2DMultisample(
        self,
        target: int,
        samples: int,
        internalformat: int,
        width: int,
        height: int,
        fixedsamplelocations: int,
    ) -> None:
        ...

    def glTexImage3DMultisample(
        self,
        target: int,
        samples: int,
        internalformat: int,
        width: int,
        height: int,
        depth: int,
        fixedsamplelocations: int,
    ) -> None:
        ...

    def glSampleMaski(self, index: int, mask: int) -> None:
        ...

    def glDrawArraysInstanced(
        self, mode: int, first: int, count: int, instancecount: int
    ) -> None:
        ...

    def glTexBuffer(self, target: int, internalformat: int, buffer: int) -> None:
        ...

    def glPrimitiveRestartIndex(self, index: int) -> None:
        ...

    def glUniformBlockBinding(
        self, program: int, uniformBlockIndex: int, uniformBlockBinding: int
    ) -> None:
        ...

    def glColorMaski(self, index: int, r: int, g: int, b: int, a: int) -> None:
        ...

    def glEnablei(self, target: int, index: int) -> None:
        ...

    def glDisablei(self, target: int, index: int) -> None:
        ...

    def glIsEnabledi(self, target: int, index: int) -> int:
        ...

    def glBeginTransformFeedback(self, primitiveMode: int) -> None:
        ...

    def glEndTransformFeedback(self) -> None:
        ...

    def glBindBufferBase(self, target: int, index: int, buffer: int) -> None:
        ...

    def glClampColor(self, target: int, clamp: int) -> None:
        ...

    def glBeginConditionalRender(self, id: int, mode: int) -> None:
        ...

    def glEndConditionalRender(self) -> None:
        ...

    def glUniform1ui(self, location: int, v0: int) -> None:
        ...

    def glUniform2ui(self, location: int, v0: int, v1: int) -> None:
        ...

    def glUniform3ui(self, location: int, v0: int, v1: int, v2: int) -> None:
        ...

    def glUniform4ui(self, location: int, v0: int, v1: int, v2: int, v3: int) -> None:
        ...

    def glClearBufferfi(
        self, buffer: int, drawbuffer: int, depth: float, stencil: int
    ) -> None:
        ...

    def glIsRenderbuffer(self, renderbuffer: int) -> int:
        ...

    def glBindRenderbuffer(self, target: int, renderbuffer: int) -> None:
        ...

    def glRenderbufferStorage(
        self, target: int, internalformat: int, width: int, height: int
    ) -> None:
        ...

    def glIsFramebuffer(self, framebuffer: int) -> int:
        ...

    def glBindFramebuffer(self, target: int, framebuffer: int) -> None:
        ...

    def glCheckFramebufferStatus(self, target: int) -> int:
        ...

    def glFramebufferTexture1D(
        self, target: int, attachment: int, textarget: int, texture: int, level: int
    ) -> None:
        ...

    def glFramebufferTexture2D(
        self, target: int, attachment: int, textarget: int, texture: int, level: int
    ) -> None:
        ...

    def glFramebufferTexture3D(
        self,
        target: int,
        attachment: int,
        textarget: int,
        texture: int,
        level: int,
        zoffset: int,
    ) -> None:
        ...

    def glFramebufferRenderbuffer(
        self, target: int, attachment: int, renderbuffertarget: int, renderbuffer: int
    ) -> None:
        ...

    def glGenerateMipmap(self, target: int) -> None:
        ...

    def glBlitFramebuffer(
        self,
        srcX0: int,
        srcY0: int,
        srcX1: int,
        srcY1: int,
        dstX0: int,
        dstY0: int,
        dstX1: int,
        dstY1: int,
        mask: int,
        filter: int,
    ) -> None:
        ...

    def glRenderbufferStorageMultisample(
        self, target: int, samples: int, internalformat: int, width: int, height: int
    ) -> None:
        ...

    def glFramebufferTextureLayer(
        self, target: int, attachment: int, texture: int, level: int, layer: int
    ) -> None:
        ...

    def glBindVertexArray(self, array: int) -> None:
        ...

    def glIsVertexArray(self, array: int) -> int:
        ...

    def glBlendEquationSeparate(self, modeRGB: int, modeAlpha: int) -> None:
        ...

    def glDrawBuffers(self, n: int, bufs: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glStencilOpSeparate(
        self, face: int, sfail: int, dpfail: int, dppass: int
    ) -> None:
        ...

    def glStencilFuncSeparate(self, face: int, func: int, ref: int, mask: int) -> None:
        ...

    def glStencilMaskSeparate(self, face: int, mask: int) -> None:
        ...

    def glAttachShader(self, program: int, shader: int) -> None:
        ...

    def glBindAttribLocation(self, program: int, index: int, name: str) -> None:
        ...

    def glCompileShader(self, shader: int) -> None:
        ...

    def glCreateProgram(self) -> int:
        ...

    def glCreateShader(self, type: int) -> int:
        ...

    def glDeleteProgram(self, program: int) -> None:
        ...

    def glDeleteShader(self, shader: int) -> None:
        ...

    def glDetachShader(self, program: int, shader: int) -> None:
        ...

    def glDisableVertexAttribArray(self, index: int) -> None:
        ...

    def glEnableVertexAttribArray(self, index: int) -> None:
        ...

    def glGetActiveAttrib(
        self, program: int, index: int
    ) -> typing.Tuple[str, int, int]:
        ...

    def glGetActiveUniform(
        self, program: int, index: int
    ) -> typing.Tuple[str, int, int]:
        ...

    def glGetAttachedShaders(self, program: int) -> typing.Tuple[int, ...]:
        ...

    def glGetAttribLocation(self, program: int, name: str) -> int:
        ...

    def glGetProgramiv(
        self, program: int, pname: int
    ) -> typing.Union[int, typing.Tuple[int, int, int]]:
        ...

    def glGetProgramInfoLog(self, program: int) -> bytes:
        ...

    def glGetShaderiv(self, shader: int, pname: int) -> int:
        ...

    def glGetShaderInfoLog(self, shader: int) -> bytes:
        ...

    def glGetShaderSource(self, shader: int) -> bytes:
        ...

    def glGetUniformLocation(self, program: int, name: str) -> int:
        ...

    def glGetVertexAttribdv(
        self, index: int, pname: int
    ) -> typing.Union[float, typing.Tuple[float, float, float, float]]:
        ...

    def glGetVertexAttribfv(
        self, index: int, pname: int
    ) -> typing.Union[float, typing.Tuple[float, float, float, float]]:
        ...

    def glGetVertexAttribiv(
        self, index: int, pname: int
    ) -> typing.Union[int, typing.Tuple[int, int, int, int]]:
        ...

    def glIsProgram(self, program: int) -> int:
        ...

    def glIsShader(self, shader: int) -> int:
        ...

    def glLinkProgram(self, program: int) -> None:
        ...

    def glUseProgram(self, program: int) -> None:
        ...

    def glUniform1f(self, location: int, v0: float) -> None:
        ...

    def glUniform2f(self, location: int, v0: float, v1: float) -> None:
        ...

    def glUniform3f(self, location: int, v0: float, v1: float, v2: float) -> None:
        ...

    def glUniform4f(
        self, location: int, v0: float, v1: float, v2: float, v3: float
    ) -> None:
        ...

    def glUniform1i(self, location: int, v0: int) -> None:
        ...

    def glUniform2i(self, location: int, v0: int, v1: int) -> None:
        ...

    def glUniform3i(self, location: int, v0: int, v1: int, v2: int) -> None:
        ...

    def glUniform4i(self, location: int, v0: int, v1: int, v2: int, v3: int) -> None:
        ...

    def glUniform1fv(self, location: int, count: int, value: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glUniform2fv(self, location: int, count: int, value: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glUniform3fv(self, location: int, count: int, value: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glUniform4fv(self, location: int, count: int, value: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glUniform1iv(self, location: int, count: int, value: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glUniform2iv(self, location: int, count: int, value: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glUniform3iv(self, location: int, count: int, value: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glUniform4iv(self, location: int, count: int, value: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glUniformMatrix2fv(
        self, location: int, count: int, transpose: int, value: PYQT_OPENGL_ARRAY
    ) -> None:
        ...

    def glUniformMatrix3fv(
        self, location: int, count: int, transpose: int, value: PYQT_OPENGL_ARRAY
    ) -> None:
        ...

    def glUniformMatrix4fv(
        self, location: int, count: int, transpose: int, value: PYQT_OPENGL_ARRAY
    ) -> None:
        ...

    def glValidateProgram(self, program: int) -> None:
        ...

    def glVertexAttribPointer(
        self,
        index: int,
        size: int,
        type: int,
        normalized: int,
        stride: int,
        pointer: PYQT_OPENGL_BOUND_ARRAY,
    ) -> None:
        ...

    def glGenQueries(self, n: int) -> typing.Union[int, typing.Tuple[int, ...]]:
        ...

    def glDeleteQueries(self, n: int, ids: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glIsQuery(self, id: int) -> int:
        ...

    def glBeginQuery(self, target: int, id: int) -> None:
        ...

    def glEndQuery(self, target: int) -> None:
        ...

    def glGetQueryiv(self, target: int, pname: int) -> int:
        ...

    def glBindBuffer(self, target: int, buffer: int) -> None:
        ...

    def glDeleteBuffers(self, n: int, buffers: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glGenBuffers(self, n: int) -> typing.Union[int, typing.Tuple[int, ...]]:
        ...

    def glIsBuffer(self, buffer: int) -> int:
        ...

    def glBufferData(
        self, target: int, size: int, data: PYQT_OPENGL_ARRAY, usage: int
    ) -> None:
        ...

    def glBufferSubData(
        self, target: int, offset: int, size: int, data: PYQT_OPENGL_ARRAY
    ) -> None:
        ...

    def glUnmapBuffer(self, target: int) -> int:
        ...

    def glGetBufferParameteriv(self, target: int, pname: int) -> int:
        ...

    def glBlendFuncSeparate(
        self, sfactorRGB: int, dfactorRGB: int, sfactorAlpha: int, dfactorAlpha: int
    ) -> None:
        ...

    def glPointParameterf(self, pname: int, param: float) -> None:
        ...

    def glPointParameterfv(self, pname: int, params: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glPointParameteri(self, pname: int, param: int) -> None:
        ...

    def glPointParameteriv(self, pname: int, params: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glActiveTexture(self, texture: int) -> None:
        ...

    def glSampleCoverage(self, value: float, invert: int) -> None:
        ...

    def glCompressedTexImage3D(
        self,
        target: int,
        level: int,
        internalformat: int,
        width: int,
        height: int,
        depth: int,
        border: int,
        imageSize: int,
        data: PYQT_OPENGL_ARRAY,
    ) -> None:
        ...

    def glCompressedTexImage2D(
        self,
        target: int,
        level: int,
        internalformat: int,
        width: int,
        height: int,
        border: int,
        imageSize: int,
        data: PYQT_OPENGL_ARRAY,
    ) -> None:
        ...

    def glCompressedTexImage1D(
        self,
        target: int,
        level: int,
        internalformat: int,
        width: int,
        border: int,
        imageSize: int,
        data: PYQT_OPENGL_ARRAY,
    ) -> None:
        ...

    def glCompressedTexSubImage3D(
        self,
        target: int,
        level: int,
        xoffset: int,
        yoffset: int,
        zoffset: int,
        width: int,
        height: int,
        depth: int,
        format: int,
        imageSize: int,
        data: PYQT_OPENGL_ARRAY,
    ) -> None:
        ...

    def glCompressedTexSubImage2D(
        self,
        target: int,
        level: int,
        xoffset: int,
        yoffset: int,
        width: int,
        height: int,
        format: int,
        imageSize: int,
        data: PYQT_OPENGL_ARRAY,
    ) -> None:
        ...

    def glCompressedTexSubImage1D(
        self,
        target: int,
        level: int,
        xoffset: int,
        width: int,
        format: int,
        imageSize: int,
        data: PYQT_OPENGL_ARRAY,
    ) -> None:
        ...

    def glBlendColor(self, red: float, green: float, blue: float, alpha: float) -> None:
        ...

    def glBlendEquation(self, mode: int) -> None:
        ...

    def glDrawRangeElements(
        self,
        mode: int,
        start: int,
        end: int,
        count: int,
        type: int,
        indices: PYQT_OPENGL_ARRAY,
    ) -> None:
        ...

    def glTexImage3D(
        self,
        target: int,
        level: int,
        internalformat: int,
        width: int,
        height: int,
        depth: int,
        border: int,
        format: int,
        type: int,
        pixels: PYQT_OPENGL_ARRAY,
    ) -> None:
        ...

    def glTexSubImage3D(
        self,
        target: int,
        level: int,
        xoffset: int,
        yoffset: int,
        zoffset: int,
        width: int,
        height: int,
        depth: int,
        format: int,
        type: int,
        pixels: PYQT_OPENGL_ARRAY,
    ) -> None:
        ...

    def glCopyTexSubImage3D(
        self,
        target: int,
        level: int,
        xoffset: int,
        yoffset: int,
        zoffset: int,
        x: int,
        y: int,
        width: int,
        height: int,
    ) -> None:
        ...

    def glDrawArrays(self, mode: int, first: int, count: int) -> None:
        ...

    def glDrawElements(
        self, mode: int, count: int, type: int, indices: PYQT_OPENGL_ARRAY
    ) -> None:
        ...

    def glPolygonOffset(self, factor: float, units: float) -> None:
        ...

    def glCopyTexImage1D(
        self,
        target: int,
        level: int,
        internalformat: int,
        x: int,
        y: int,
        width: int,
        border: int,
    ) -> None:
        ...

    def glCopyTexImage2D(
        self,
        target: int,
        level: int,
        internalformat: int,
        x: int,
        y: int,
        width: int,
        height: int,
        border: int,
    ) -> None:
        ...

    def glCopyTexSubImage1D(
        self, target: int, level: int, xoffset: int, x: int, y: int, width: int
    ) -> None:
        ...

    def glCopyTexSubImage2D(
        self,
        target: int,
        level: int,
        xoffset: int,
        yoffset: int,
        x: int,
        y: int,
        width: int,
        height: int,
    ) -> None:
        ...

    def glTexSubImage1D(
        self,
        target: int,
        level: int,
        xoffset: int,
        width: int,
        format: int,
        type: int,
        pixels: PYQT_OPENGL_ARRAY,
    ) -> None:
        ...

    def glTexSubImage2D(
        self,
        target: int,
        level: int,
        xoffset: int,
        yoffset: int,
        width: int,
        height: int,
        format: int,
        type: int,
        pixels: PYQT_OPENGL_ARRAY,
    ) -> None:
        ...

    def glBindTexture(self, target: int, texture: int) -> None:
        ...

    def glDeleteTextures(self, n: int, textures: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glGenTextures(self, n: int) -> typing.Union[int, typing.Tuple[int, ...]]:
        ...

    def glIsTexture(self, texture: int) -> int:
        ...

    def glCullFace(self, mode: int) -> None:
        ...

    def glFrontFace(self, mode: int) -> None:
        ...

    def glHint(self, target: int, mode: int) -> None:
        ...

    def glLineWidth(self, width: float) -> None:
        ...

    def glPointSize(self, size: float) -> None:
        ...

    def glPolygonMode(self, face: int, mode: int) -> None:
        ...

    def glScissor(self, x: int, y: int, width: int, height: int) -> None:
        ...

    def glTexParameterf(self, target: int, pname: int, param: float) -> None:
        ...

    def glTexParameterfv(
        self, target: int, pname: int, params: PYQT_OPENGL_ARRAY
    ) -> None:
        ...

    def glTexParameteri(self, target: int, pname: int, param: int) -> None:
        ...

    def glTexParameteriv(
        self, target: int, pname: int, params: PYQT_OPENGL_ARRAY
    ) -> None:
        ...

    def glTexImage1D(
        self,
        target: int,
        level: int,
        internalformat: int,
        width: int,
        border: int,
        format: int,
        type: int,
        pixels: PYQT_OPENGL_ARRAY,
    ) -> None:
        ...

    def glTexImage2D(
        self,
        target: int,
        level: int,
        internalformat: int,
        width: int,
        height: int,
        border: int,
        format: int,
        type: int,
        pixels: PYQT_OPENGL_ARRAY,
    ) -> None:
        ...

    def glDrawBuffer(self, mode: int) -> None:
        ...

    def glClear(self, mask: int) -> None:
        ...

    def glClearColor(self, red: float, green: float, blue: float, alpha: float) -> None:
        ...

    def glClearStencil(self, s: int) -> None:
        ...

    def glClearDepth(self, depth: float) -> None:
        ...

    def glStencilMask(self, mask: int) -> None:
        ...

    def glColorMask(self, red: int, green: int, blue: int, alpha: int) -> None:
        ...

    def glDepthMask(self, flag: int) -> None:
        ...

    def glDisable(self, cap: int) -> None:
        ...

    def glEnable(self, cap: int) -> None:
        ...

    def glFinish(self) -> None:
        ...

    def glFlush(self) -> None:
        ...

    def glBlendFunc(self, sfactor: int, dfactor: int) -> None:
        ...

    def glLogicOp(self, opcode: int) -> None:
        ...

    def glStencilFunc(self, func: int, ref: int, mask: int) -> None:
        ...

    def glStencilOp(self, fail: int, zfail: int, zpass: int) -> None:
        ...

    def glDepthFunc(self, func: int) -> None:
        ...

    def glPixelStoref(self, pname: int, param: float) -> None:
        ...

    def glPixelStorei(self, pname: int, param: int) -> None:
        ...

    def glReadBuffer(self, mode: int) -> None:
        ...

    def glReadPixels(
        self, x: int, y: int, width: int, height: int, format: int, type: int
    ) -> typing.Union[typing.Tuple[float, ...], typing.Tuple[int, ...]]:
        ...

    def glGetBooleanv(self, pname: int) -> typing.Union[bool, typing.Tuple[bool, ...]]:
        ...

    def glGetDoublev(self, pname: int) -> typing.Union[float, typing.Tuple[float, ...]]:
        ...

    def glGetError(self) -> int:
        ...

    def glGetFloatv(self, pname: int) -> typing.Union[float, typing.Tuple[float, ...]]:
        ...

    def glGetIntegerv(self, pname: int) -> typing.Union[int, typing.Tuple[int, ...]]:
        ...

    def glGetString(self, name: int) -> str:
        ...

    def glGetTexParameterfv(
        self, target: int, pname: int
    ) -> typing.Union[float, typing.Tuple[float, float, float, float]]:
        ...

    def glGetTexParameteriv(
        self, target: int, pname: int
    ) -> typing.Union[int, typing.Tuple[int, int, int, int]]:
        ...

    def glGetTexLevelParameterfv(self, target: int, level: int, pname: int) -> float:
        ...

    def glGetTexLevelParameteriv(self, target: int, level: int, pname: int) -> int:
        ...

    def glIsEnabled(self, cap: int) -> int:
        ...

    def glDepthRange(self, nearVal: float, farVal: float) -> None:
        ...

    def glViewport(self, x: int, y: int, width: int, height: int) -> None:
        ...

    def initializeOpenGLFunctions(self) -> bool:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QMenuBar(QWidget):
    """
    https://doc.qt.io/qt-6/qmenubar.html

    **Detailed Description**

    A menu bar consists of a list of pull-down menu items. You add menu items
    with **addMenu** (). For example, assuming that `menubar` is a pointer to a
    QMenuBar and `fileMenu` is a pointer to a **QMenu** , the following
    statement inserts the menu into the menu bar:

    menubar->addMenu(fileMenu);

    The ampersand in the menu item's text sets Alt+F as a shortcut for this
    menu. (You can use "&&" to get a real ampersand in the menu bar.)

    There is no need to lay out a menu bar. It automatically sets its own
    geometry to the top of the parent widget and changes it appropriately
    whenever the parent is resized.

    **Usage**

    In most main window style applications you would use the **menuBar** ()
    function provided in **QMainWindow** , adding **QMenu** s to the menu bar
    and adding **QAction** s to the pop-up menus.

    Example (from the **Menus**  example):

    fileMenu = menuBar()->addMenu(tr("&File"));
    fileMenu->addAction(newAct);

    Menu items may be removed with **removeAction** ().

    Widgets can be added to menus by using instances of the **QWidgetAction**
    class to hold them. These actions can then be inserted into menus in the
    usual way; see the **QMenu**  documentation for more details.

    **Platform Dependent Look and Feel**

    Different platforms have different requirements for the appearance of menu
    bars and their behavior when the user interacts with them. For example,
    Windows systems are often configured so that the underlined character
    mnemonics that indicate keyboard shortcuts for items in the menu bar are
    only shown when the **Alt** key is pressed.

    **QMenuBar as a Global Menu Bar**

    On macOS and on certain Linux desktop environments such as Ubuntu Unity,
    QMenuBar is a wrapper for using the system-wide menu bar. If you have
    multiple menu bars in one dialog the outermost menu bar (normally inside a
    widget with widget flag **Qt::Window** ) will be used for the system-wide
    menu bar.

    Qt for macOS also provides a menu bar merging feature to make QMenuBar
    conform more closely to accepted macOS menu bar layout. The merging
    functionality is based on string matching the title of a **QMenu**  entry.
    These strings are translated (using **QObject::tr** ()) in the "QMenuBar"
    context. If an entry is moved its slots will still fire as if it was in the
    original place. The table below outlines the strings looked for and where
    the entry is placed if matched:

    String matchesPlacementNotes
    about.*Application Menu | About <application
    name>The application name is fetched from the `Info.plist` file (see note
    below). If this entry is not found no About item will appear in the
    Application Menu.
    config, options, setup, settings or
    preferencesApplication Menu | PreferencesIf this entry is not found the
    Settings item will be disabled
    quit or exitApplication Menu | Quit
    <application name>If this entry is not found a default Quit item will be
    created to call **QCoreApplication::quit** ()

    You can override this behavior by using the **QAction::menuRole** ()
    property.

    If you want all windows in a Mac application to share one menu bar, you must
    create a menu bar that does not have a parent. Create a parent-less menu bar
    this way:

    **QMenuBar**  *menuBar = new **QMenuBar** (nullptr);

    **Note:** Do **not** call **QMainWindow::menuBar** () to create the shared
    menu bar, because that menu bar will have the **QMainWindow**  as its
    parent. That menu bar would only be displayed for the parent **QMainWindow**
    .

    **Note:** The text used for the application name in the macOS menu bar is
    obtained from the value set in the `Info.plist` file in the application's
    bundle. See **Qt for macOS - Deployment**  for more information.

    **Note:** On Linux, if the com.canonical.AppMenu.Registrar service is
    available on the D-Bus session bus, then Qt will communicate with it to
    install the application's menus into the global menu bar, as described.

    **Examples**

    The **Menus**  example shows how to use QMenuBar and **QMenu** . The other
    **main window application examples**  also provide menus using these
    classes.

    **See also** **QMenu** , **QShortcut** , **QAction** , **Introduction to
    Apple Human Interface Guidelines** , **GUI Design Handbook: Menu Bar** , and
    **Menus Example** .
    """

    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qmenubar.html#QMenuBar

        **QMenuBar::QMenuBar(QWidget * parent = nullptr)**

        Constructs a menu bar with parent **parent**.
        """
        ...

    def setNativeMenuBar(self, nativeMenuBar: bool) -> None:
        """
        https://doc.qt.io/qt-6/qmenubar.html#nativeMenuBar-prop

        **nativeMenuBar : bool**

        This property holds whether or not a menubar will be used as a native
        menubar on platforms that support it

        This property specifies whether or not the menubar should be used as a
        native menubar on platforms that support it. The currently supported
        platforms are macOS, and Linux desktops which use the
        com.canonical.dbusmenu D-Bus interface (such as Ubuntu Unity). If this
        property is `true`, the menubar is used in the native menubar and is not
        in the window of its parent; if `false` the menubar remains in the
        window. On other platforms, setting this attribute has no effect, and
        reading this attribute will always return `false`.

        The default is to follow whether the **Qt::AA_DontUseNativeMenuBar**
        attribute is set for the application. Explicitly setting this property
        overrides the presence (or absence) of the attribute.

        **Access functions:**

        bool **isNativeMenuBar** () const
        void **setNativeMenuBar** (bool
        **nativeMenuBar** )

        **Member Function Documentation**
        """
        ...

    def isNativeMenuBar(self) -> bool:
        ...

    def timerEvent(self, a0: QtCore.QTimerEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmenubar.html#timerEvent

        **[override virtual protected] void QMenuBar::timerEvent(QTimerEvent * e
        )**

        Reimplements: **QObject::timerEvent** (QTimerEvent *event).
        """
        ...

    def event(self, a0: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qmenubar.html#event

        **[override virtual protected] bool QMenuBar::event(QEvent * e )**

        Reimplements: **QWidget::event** (QEvent *event).
        """
        ...

    def eventFilter(self, a0: QtCore.QObject, a1: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qmenubar.html#eventFilter

        **[override virtual protected] bool QMenuBar::eventFilter(QObject *
        object , QEvent * event )**

        Reimplements: **QObject::eventFilter** (QObject *watched, QEvent
        *event).
        """
        ...

    def focusInEvent(self, a0: QtGui.QFocusEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmenubar.html#focusInEvent

        **[override virtual protected] void QMenuBar::focusInEvent(QFocusEvent
        *)**

        Reimplements: **QWidget::focusInEvent** (QFocusEvent *event).
        """
        ...

    def focusOutEvent(self, a0: QtGui.QFocusEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmenubar.html#focusOutEvent

        **[override virtual protected] void QMenuBar::focusOutEvent(QFocusEvent
        *)**

        Reimplements: **QWidget::focusOutEvent** (QFocusEvent *event).
        """
        ...

    def actionEvent(self, a0: QtGui.QActionEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmenubar.html#actionEvent

        **[override virtual protected] void QMenuBar::actionEvent(QActionEvent *
        e )**

        Reimplements: **QWidget::actionEvent** (QActionEvent *event).
        """
        ...

    def resizeEvent(self, a0: QtGui.QResizeEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmenubar.html#resizeEvent

        **[override virtual protected] void QMenuBar::resizeEvent(QResizeEvent
        *)**

        Reimplements: **QWidget::resizeEvent** (QResizeEvent *event).
        """
        ...

    def paintEvent(self, a0: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmenubar.html#paintEvent

        **[override virtual protected] void QMenuBar::paintEvent(QPaintEvent * e
        )**

        Reimplements: **QWidget::paintEvent** (QPaintEvent *event).
        """
        ...

    def leaveEvent(self, a0: QtCore.QEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmenubar.html#leaveEvent

        **[override virtual protected] void QMenuBar::leaveEvent(QEvent *)**

        Reimplements: **QWidget::leaveEvent** (QEvent *event).
        """
        ...

    def mouseMoveEvent(self, a0: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmenubar.html#mouseMoveEvent

        **[override virtual protected] void QMenuBar::mouseMoveEvent(QMouseEvent
        * e )**

        Reimplements: **QWidget::mouseMoveEvent** (QMouseEvent *event).
        """
        ...

    def mousePressEvent(self, a0: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmenubar.html#mousePressEvent

        **[override virtual protected] void
        QMenuBar::mousePressEvent(QMouseEvent * e )**

        Reimplements: **QWidget::mousePressEvent** (QMouseEvent *event).
        """
        ...

    def mouseReleaseEvent(self, a0: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmenubar.html#mouseReleaseEvent

        **[override virtual protected] void
        QMenuBar::mouseReleaseEvent(QMouseEvent * e )**

        Reimplements: **QWidget::mouseReleaseEvent** (QMouseEvent *event).
        """
        ...

    def keyPressEvent(self, a0: QtGui.QKeyEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmenubar.html#keyPressEvent

        **[override virtual protected] void QMenuBar::keyPressEvent(QKeyEvent *
        e )**

        Reimplements: **QWidget::keyPressEvent** (QKeyEvent *event).
        """
        ...

    def changeEvent(self, a0: QtCore.QEvent) -> None:
        """
        https://doc.qt.io/qt-6/qmenubar.html#changeEvent

        **[override virtual protected] void QMenuBar::changeEvent(QEvent * e )**

        Reimplements: **QWidget::changeEvent** (QEvent *event).
        """
        ...

    def initStyleOption(
        self, option: "QStyleOptionMenuItem", action: QtGui.QAction
    ) -> None:
        """
        https://doc.qt.io/qt-6/qmenubar.html#initStyleOption

        **[virtual protected] void
        QMenuBar::initStyleOption(QStyleOptionMenuItem * option , const QAction
        * action ) const**

        Initialize **option** with the values from the menu bar and information
        from **action**. This method is useful for subclasses when they need a
        **QStyleOptionMenuItem** , but don't want to fill in all the information
        themselves.

        **See also** **QStyleOption::initFrom** () and
        **QMenu::initStyleOption** ().
        """
        ...

    def setVisible(self, visible: bool) -> None:
        """
        https://doc.qt.io/qt-6/qmenubar.html#setVisible

        **[override virtual slot] void QMenuBar::setVisible(bool visible )**

        Reimplements an access function for property: **QWidget::visible** .
        """
        ...

    def cornerWidget(self, corner: QtCore.Qt.Corner = ...) -> QWidget:
        """
        https://doc.qt.io/qt-6/qmenubar.html#cornerWidget

        **QWidget *QMenuBar::cornerWidget(Qt::Corner corner =
        Qt::TopRightCorner) const**

        Returns the widget on the left of the first or on the right of the last
        menu item, depending on **corner**.

        **Note:** Using a corner other than **Qt::TopRightCorner**  or
        **Qt::TopLeftCorner**  will result in a warning.

        **See also** **setCornerWidget** ().
        """
        ...

    def setCornerWidget(self, widget: QWidget, corner: QtCore.Qt.Corner = ...) -> None:
        """
        https://doc.qt.io/qt-6/qmenubar.html#setCornerWidget

        **void QMenuBar::setCornerWidget(QWidget * widget , Qt::Corner corner =
        Qt::TopRightCorner)**

        This sets the given **widget** to be shown directly on the left of the
        first menu item, or on the right of the last menu item, depending on
        **corner**.

        The menu bar takes ownership of **widget** , reparenting it into the
        menu bar. However, if the **corner** already contains a widget, this
        previous widget will no longer be managed and will still be a visible
        child of the menu bar.

        **Note:** Using a corner other than **Qt::TopRightCorner**  or
        **Qt::TopLeftCorner**  will result in a warning.

        **See also** **cornerWidget** ().
        """
        ...

    def actionAt(self, a0: QtCore.QPoint) -> QtGui.QAction:
        """
        https://doc.qt.io/qt-6/qmenubar.html#actionAt

        **QAction *QMenuBar::actionAt(const QPoint & pt ) const**

        Returns the **QAction**  at **pt**. Returns `nullptr` if there is no
        action at **pt** or if the location has a separator.

        **See also** **addAction** () and **addSeparator** ().
        """
        ...

    def actionGeometry(self, a0: QtGui.QAction) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qmenubar.html#actionGeometry

        **QRect QMenuBar::actionGeometry(QAction * act ) const**

        Returns the geometry of action **act** as a **QRect** .

        **See also** **actionAt** ().
        """
        ...

    def heightForWidth(self, a0: int) -> int:
        """
        https://doc.qt.io/qt-6/qmenubar.html#heightForWidth

        **[override virtual] int QMenuBar::heightForWidth(int) const**

        Reimplements: **QWidget::heightForWidth(int w) const** .
        """
        ...

    def minimumSizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qmenubar.html#minimumSizeHint

        **[override virtual] QSize QMenuBar::minimumSizeHint() const**

        Reimplements an access function for property:
        **QWidget::minimumSizeHint** .
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qmenubar.html#sizeHint

        **[override virtual] QSize QMenuBar::sizeHint() const**

        Reimplements an access function for property: **QWidget::sizeHint** .
        """
        ...

    def isDefaultUp(self) -> bool:
        ...

    def setDefaultUp(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qmenubar.html#defaultUp-prop

        **defaultUp : bool**

        This property holds the popup orientation

        The default popup orientation. By default, menus pop "down" the screen.
        By setting the property to true, the menu will pop "up". You might call
        this for menus that are **below** the document to which they refer.

        If the menu would not fit on the screen, the other direction is used
        automatically.

        **Access functions:**

        bool **isDefaultUp** () const
        void **setDefaultUp** (bool)
        """
        ...

    def setActiveAction(self, action: QtGui.QAction) -> None:
        """
        https://doc.qt.io/qt-6/qmenubar.html#setActiveAction

        **void QMenuBar::setActiveAction(QAction * act )**

        Sets the currently highlighted action to **act**.

        **See also** **activeAction** ().
        """
        ...

    def activeAction(self) -> QtGui.QAction:
        """
        https://doc.qt.io/qt-6/qmenubar.html#activeAction

        **QAction *QMenuBar::activeAction() const**

        Returns the **QAction**  that is currently highlighted, if any, else
        `nullptr`.

        **See also** **setActiveAction** ().
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qmenubar.html#clear

        **void QMenuBar::clear()**

        Removes all the actions from the menu bar.

        **Note:** On macOS, menu items that have been merged to the system menu
        bar are not removed by this function. One way to handle this would be to
        remove the extra actions yourself. You can set the **menu role**  on the
        different menus, so that you know ahead of time which menu items get
        merged and which do not. Then decide what to recreate or remove
        yourself.

        **See also** **removeAction** ().
        """
        ...

    def insertSeparator(self, before: QtGui.QAction) -> QtGui.QAction:
        """
        https://doc.qt.io/qt-6/qmenubar.html#insertSeparator

        **QAction *QMenuBar::insertSeparator(QAction * before )**

        This convenience function creates a new separator action, i.e. an action
        with **QAction::isSeparator** () returning true. The function inserts
        the newly created action into this menu bar's list of actions before
        action **before** and returns it.

        **See also** **QWidget::insertAction** () and **addSeparator** ().
        """
        ...

    def insertMenu(self, before: QtGui.QAction, menu: QMenu) -> QtGui.QAction:
        """
        https://doc.qt.io/qt-6/qmenubar.html#insertMenu

        **QAction *QMenuBar::insertMenu(QAction * before , QMenu * menu )**

        This convenience function inserts **menu** before action **before** and
        returns the menus menuAction().

        **See also** **QWidget::insertAction** () and **addMenu** ().
        """
        ...

    def addSeparator(self) -> QtGui.QAction:
        """
        https://doc.qt.io/qt-6/qmenubar.html#addSeparator

        **QAction *QMenuBar::addSeparator()**

        Appends a separator to the menu.
        """
        ...

    @typing.overload
    def addMenu(self, menu: QMenu) -> QtGui.QAction:
        """
        https://doc.qt.io/qt-6/qmenubar.html#addMenu

        **QAction *QMenuBar::addMenu(QMenu * menu )**

        Appends **menu** to the menu bar. Returns the menu's menuAction(). The
        menu bar does not take ownership of the menu.

        **Note:** The returned **QAction**  object can be used to hide the
        corresponding menu.

        **See also** **QWidget::addAction** () and **QMenu::menuAction** ().
        """
        ...

    @typing.overload
    def addMenu(self, title: str) -> QMenu:
        """
        https://doc.qt.io/qt-6/qmenubar.html#addMenu-1

        **QMenu *QMenuBar::addMenu(const QString & title )**

        Appends a new **QMenu**  with **title** to the menu bar. The menu bar
        takes ownership of the menu. Returns the new menu.

        **See also** **QWidget::addAction** () and **QMenu::menuAction** ().
        """
        ...

    @typing.overload
    def addMenu(self, icon: QtGui.QIcon, title: str) -> QMenu:
        """
        https://doc.qt.io/qt-6/qmenubar.html#addMenu-2

        **QMenu *QMenuBar::addMenu(const QIcon & icon , const QString & title
        )**

        Appends a new **QMenu**  with **icon** and **title** to the menu bar.
        The menu bar takes ownership of the menu. Returns the new menu.

        **See also** **QWidget::addAction** () and **QMenu::menuAction** ().
        """
        ...

    @typing.overload
    def addAction(self, a0: QtGui.QAction) -> None:
        """
        https://doc.qt.io/qt-6/qmenubar.html#addAction

        **QAction *QMenuBar::addAction(const QString & text )**

        This convenience function creates a new action with **text**. The
        function adds the newly created action to the menu's list of actions,
        and returns it.

        **See also** **QWidget::addAction** () and **QWidget::actions** ().
        """
        ...

    @typing.overload
    def addAction(self, text: str) -> QtGui.QAction:
        """
        https://doc.qt.io/qt-6/qmenubar.html#addAction-1

        **QAction *QMenuBar::addAction(const QString & text , const QObject *
        receiver , const char * member )**

        This is an overloaded function.

        This convenience function creates a new action with the given **text**.
        The action's **triggered** () signal is connected to the **receiver** 's
        **member** slot. The function adds the newly created action to the
        menu's list of actions and returns it.

        **See also** **QWidget::addAction** () and **QWidget::actions** ().
        """
        ...

    @typing.overload
    def addAction(self, text: str, slot: PYQT_SLOT) -> QtGui.QAction:
        """
        https://doc.qt.io/qt-6/qmenubar.html#addAction-2

        **[since 5.11] template <typename Obj, typename
        PointerToMemberFunctionOrFunctor> QAction *QMenuBar::addAction(const
        QString & text , const Obj * receiver , PointerToMemberFunctionOrFunctor
        method )**

        This is an overloaded function.

        This convenience function creates a new action with the given **text**.
        The action's **triggered** () signal is connected to the **method** of
        the **receiver**. The function adds the newly created action to the
        menu's list of actions and returns it.

        **QMenuBar**  takes ownership of the returned **QAction** .

        This function was introduced in Qt 5.11.

        **See also** **QWidget::addAction** () and **QWidget::actions** ().
        """
        ...

    @property
    def hovered(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qmenubar.html#hovered

        **[signal] void QMenuBar::hovered(QAction * action )**

        This signal is emitted when a menu action is highlighted; **action** is
        the action that caused the event to be sent.

        Often this is used to update status information.

        **See also** **triggered** () and **QAction::hovered** ().
        """
        ...

    @property
    def triggered(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qmenubar.html#triggered

        **[signal] void QMenuBar::triggered(QAction * action )**

        This signal is emitted when an action in a menu belonging to this
        menubar is triggered as a result of a mouse click; **action** is the
        action that caused the signal to be emitted.

        **Note:****QMenuBar**  has to have ownership of the **QMenu**  in order
        this signal to work.

        Normally, you connect each menu action to a single slot using
        **QAction::triggered** (), but sometimes you will want to connect
        several items to a single slot (most often if the user selects from an
        array). This signal is useful in such cases.

        **See also** **hovered** () and **QAction::triggered** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QTableWidgetSelectionRange(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qtablewidgetselectionrange.html

    **Detailed Description**

    The QTableWidgetSelectionRange class stores the top left and bottom right
    rows and columns of a selection range in a table. The selections in the
    table may consist of several selection ranges.

    **Note:** If the item within the selection range is marked as not
    selectable, e.g., `itemFlags() & Qt::ItemIsSelectable == 0` then it will not
    appear in the selection range.

    **See also** **QTableWidget** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidgetselectionrange.html#QTableWidgetSelec
        tionRange

        **QTableWidgetSelectionRange::QTableWidgetSelectionRange()**

        Constructs an empty table selection range, i.e. a range whose
        **rowCount** () and **columnCount** () are 0.

        **See also** **topRow** (), **leftColumn** (), **bottomRow** (), and
        **rightColumn** ().
        """
        ...

    @typing.overload
    def __init__(self, top: int, left: int, bottom: int, right: int) -> None:
        """
        https://doc.qt.io/qt-6/qtablewidgetselectionrange.html#QTableWidgetSelec
        tionRange-1

        **QTableWidgetSelectionRange::QTableWidgetSelectionRange(int top , int
        left , int bottom , int right )**

        Constructs the table selection range from the given **top** , **left** ,
        **bottom** and **right** table rows and columns.

        **See also** **topRow** (), **leftColumn** (), **bottomRow** (), and
        **rightColumn** ().
        """
        ...

    @typing.overload
    def __init__(self, a0: "QTableWidgetSelectionRange") -> None:
        """
        https://doc.qt.io/qt-6/qtablewidgetselectionrange.html#QTableWidgetSelec
        tionRange

        **QTableWidgetSelectionRange::QTableWidgetSelectionRange()**

        Constructs an empty table selection range, i.e. a range whose
        **rowCount** () and **columnCount** () are 0.

        **See also** **topRow** (), **leftColumn** (), **bottomRow** (), and
        **rightColumn** ().
        """
        ...

    def columnCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qtablewidgetselectionrange.html#columnCount

        **int QTableWidgetSelectionRange::columnCount() const**

        Returns the number of columns in the range.

        This is equivalent to **rightColumn** () - **leftColumn** () + 1.

        **See also** **rowCount** (), **leftColumn** (), and **rightColumn** ().
        """
        ...

    def rowCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qtablewidgetselectionrange.html#rowCount

        **int QTableWidgetSelectionRange::rowCount() const**

        Returns the number of rows in the range.

        This is equivalent to **bottomRow** () - **topRow** () + 1.

        **See also** **columnCount** (), **topRow** (), and **bottomRow** ().
        """
        ...

    def rightColumn(self) -> int:
        """
        https://doc.qt.io/qt-6/qtablewidgetselectionrange.html#rightColumn

        **int QTableWidgetSelectionRange::rightColumn() const**

        Returns the right column of the range.

        **See also** **leftColumn** (), **bottomRow** (), and **columnCount**
        ().
        """
        ...

    def leftColumn(self) -> int:
        """
        https://doc.qt.io/qt-6/qtablewidgetselectionrange.html#leftColumn

        **int QTableWidgetSelectionRange::leftColumn() const**

        Returns the left column of the range.

        **See also** **rightColumn** (), **topRow** (), and **columnCount** ().
        """
        ...

    def bottomRow(self) -> int:
        """
        https://doc.qt.io/qt-6/qtablewidgetselectionrange.html#bottomRow

        **int QTableWidgetSelectionRange::bottomRow() const**

        Returns the bottom row of the range.

        **See also** **topRow** (), **rightColumn** (), and **rowCount** ().
        """
        ...

    def topRow(self) -> int:
        """
        https://doc.qt.io/qt-6/qtablewidgetselectionrange.html#topRow

        **int QTableWidgetSelectionRange::topRow() const**

        Returns the top row of the range.

        **See also** **bottomRow** (), **leftColumn** (), and **rowCount** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QDnsServiceRecord(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qdnsservicerecord.html

    **Detailed Description**

    When performing a lookup on a service, zero or more records will be
    returned. Each record is represented by a QDnsServiceRecord instance.

    The meaning of the fields is defined in **RFC 2782** .

    **See also** **QDnsLookup** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qdnsservicerecord.html#QDnsServiceRecord

        **QDnsServiceRecord::QDnsServiceRecord()**

        Constructs an empty service record object.
        """
        ...

    @typing.overload
    def __init__(self, other: "QDnsServiceRecord") -> None:
        """
        https://doc.qt.io/qt-6/qdnsservicerecord.html#QDnsServiceRecord-1

        **QDnsServiceRecord::QDnsServiceRecord(const QDnsServiceRecord & other
        )**

        Constructs a copy of **other**.
        """
        ...

    def weight(self) -> int:
        """
        https://doc.qt.io/qt-6/qdnsservicerecord.html#weight

        **quint16 QDnsServiceRecord::weight() const**

        Returns the weight for this service record.

        The weight field specifies a relative weight for entries with the same
        priority. Entries with higher weights should be selected with a higher
        probability.
        """
        ...

    def timeToLive(self) -> int:
        """
        https://doc.qt.io/qt-6/qdnsservicerecord.html#timeToLive

        **quint32 QDnsServiceRecord::timeToLive() const**

        Returns the duration in seconds for which this record is valid.
        """
        ...

    def target(self) -> str:
        """
        https://doc.qt.io/qt-6/qdnsservicerecord.html#target

        **QString QDnsServiceRecord::target() const**

        Returns the domain name of the target host for this service record.
        """
        ...

    def priority(self) -> int:
        """
        https://doc.qt.io/qt-6/qdnsservicerecord.html#priority

        **quint16 QDnsServiceRecord::priority() const**

        Returns the priority for this service record.

        A client must attempt to contact the target host with the lowest-
        numbered priority.
        """
        ...

    def port(self) -> int:
        """
        https://doc.qt.io/qt-6/qdnsservicerecord.html#port

        **quint16 QDnsServiceRecord::port() const**

        Returns the port on the target host for this service record.
        """
        ...

    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qdnsservicerecord.html#name

        **QString QDnsServiceRecord::name() const**

        Returns the name for this record.
        """
        ...

    def swap(self, other: "QDnsServiceRecord") -> None:
        """
        https://doc.qt.io/qt-6/qdnsservicerecord.html#swap

        **void QDnsServiceRecord::swap(QDnsServiceRecord & other )**

        Swaps this service record instance with **other**. This function is very
        fast and never fails.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QItemEditorFactory(PyQt6.sip.wrapper):
    """
    https://doc.qt.io/qt-6/qitemeditorfactory.html

    **Detailed Description**

    When editing data in an item view, editors are created and displayed by a
    delegate. **QStyledItemDelegate** , which is the delegate by default
    installed on Qt's item views, uses a QItemEditorFactory to create editors
    for it. A default unique instance provided by QItemEditorFactory is used by
    all item delegates. If you set a new default factory with
    **setDefaultFactory** (), the new factory will be used by existing and new
    delegates.

    A factory keeps a collection of **QItemEditorCreatorBase**  instances, which
    are specialized editors that produce editors for one particular **QVariant**
    data type (All Qt models store their data in **QVariant** s).

    **Standard Editing Widgets**

    The standard factory implementation provides editors for a variety of data
    types. These are created whenever a delegate needs to provide an editor for
    data supplied by a model. The following table shows the relationship between
    types and the standard editors provided.

    TypeEditor Widget
    bool**QComboBox**
    double**QDoubleSpinBox**
    int**QSpinBox**
    unsigned int
    **QDate** **QDateEdit**
    **QDateTime**
    **QDateTimeEdit**
    **QPixmap** **QLabel**
    **QString** **QLineEdit**
    **QTime** **QTimeEdit**

    Additional editors can be registered with the **registerEditor** ()
    function.

    **See also** **QStyledItemDelegate** , **Model/View Programming** , and
    **Color Editor Factory Example** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qitemeditorfactory.html#QItemEditorFactory

        **QItemEditorFactory::QItemEditorFactory()**

        Constructs a new item editor factory.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QItemEditorFactory") -> None:
        """
        https://doc.qt.io/qt-6/qitemeditorfactory.html#QItemEditorFactory

        **QItemEditorFactory::QItemEditorFactory()**

        Constructs a new item editor factory.
        """
        ...

    @staticmethod
    def setDefaultFactory(factory: "QItemEditorFactory") -> None:
        """
        https://doc.qt.io/qt-6/qitemeditorfactory.html#setDefaultFactory

        **[static] void QItemEditorFactory::setDefaultFactory(QItemEditorFactory
        * factory )**

        Sets the default item editor factory to the given **factory**. Both new
        and existing delegates will use the new factory.

        **See also** **defaultFactory** ().
        """
        ...

    @staticmethod
    def defaultFactory() -> "QItemEditorFactory":
        """
        https://doc.qt.io/qt-6/qitemeditorfactory.html#defaultFactory

        **[static] const QItemEditorFactory
        *QItemEditorFactory::defaultFactory()**

        Returns the default item editor factory.

        **See also** **setDefaultFactory** ().
        """
        ...

    def registerEditor(self, userType: int, creator: QItemEditorCreatorBase) -> None:
        """
        https://doc.qt.io/qt-6/qitemeditorfactory.html#registerEditor

        **void QItemEditorFactory::registerEditor(int userType ,
        QItemEditorCreatorBase * creator )**

        Registers an item editor creator specified by **creator** for the given
        **userType** of data.

        **Note:** The factory takes ownership of the item editor creator and
        will destroy it if a new creator for the same type is registered later.

        **See also** **createEditor** ().
        """
        ...

    def valuePropertyName(self, userType: int) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qitemeditorfactory.html#valuePropertyName

        **[virtual] QByteArray QItemEditorFactory::valuePropertyName(int
        userType ) const**

        Returns the property name used to access data for the given **userType**
        of data.
        """
        ...

    def createEditor(self, userType: int, parent: QWidget) -> QWidget:
        """
        https://doc.qt.io/qt-6/qitemeditorfactory.html#createEditor

        **[virtual] QWidget *QItemEditorFactory::createEditor(int userType ,
        QWidget * parent ) const**

        Creates an editor widget with the given **parent** for the specified
        **userType** of data, and returns it as a **QWidget** .

        **See also** **registerEditor** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
from PyQt6 import QtCore
from PyQt6.QtQuick import *
import enum


class QSGTexture(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qsgtexture.html

    **Detailed Description**

    Users can freely implement their own texture classes to support arbitrary
    input textures, such as YUV video frames or 8 bit alpha masks. The scene
    graph provides a default implementation for RGBA textures.The default
    implementation is not instantiated directly, rather they are constructed via
    factory functions, such as **QQuickWindow::createTextureFromImage** ().

    With the default implementation, each QSGTexture is backed by a QRhiTexture,
    which in turn contains a native texture object, such as an OpenGL texture or
    a Vulkan image.

    The size in pixels is given by **textureSize** (). **hasAlphaChannel** ()
    reports if the texture contains opacity values and **hasMipmaps** () reports
    if the texture contains mipmap levels.

    **Materials**  that work with textures reimplement **updateSampledImage** ()
    to provide logic that decides which QSGTexture's underlying native texture
    should be exposed at a given shader resource binding point.

    QSGTexture does not separate image (texture) and sampler objects. The
    parameters for filtering and wrapping can be specified with
    **setMipmapFiltering** (), **setFiltering** (), **setHorizontalWrapMode** ()
    and **setVerticalWrapMode** (). The scene graph and Qt's graphics
    abstraction takes care of creating separate sampler objects, when
    applicable.

    **Texture Atlases**

    Some scene graph backends use texture atlasses, grouping multiple small
    textures into one large texture. If this is the case, the function
    **isAtlasTexture** () will return true. Atlases are used to aid the
    rendering algorithm to do better sorting which increases performance.
    Atlases are also essential for batching (merging together geometry to reduce
    the number of draw calls), because two instances of the same material using
    two different QSGTextures are not batchable, whereas if both QSGTextures
    refer to the same atlas, batching can happen, assuming the materials are
    otherwise compatible.

    The location of the texture inside the atlas is given with the
    **normalizedTextureSubRect** () function.

    If the texture is used in such a way that atlas is not preferable, the
    function **removedFromAtlas** () can be used to extract a non-atlased copy.

    **Note:** All classes with QSG prefix should be used solely on the scene
    graph's rendering thread. See **Scene Graph and Rendering**  for more
    information.

    **See also** **Scene Graph - Rendering FBOs** .
    """

    class AnisotropyLevel(enum.Enum):
        AnisotropyNone: QSGTexture = ...
        Anisotropy2x: QSGTexture = ...
        Anisotropy4x: QSGTexture = ...
        Anisotropy8x: QSGTexture = ...
        Anisotropy16x: QSGTexture = ...

    class Filtering(enum.Enum):
        None_: QSGTexture = ...
        Nearest: QSGTexture = ...
        Linear: QSGTexture = ...

    class WrapMode(enum.Enum):
        Repeat: QSGTexture = ...
        ClampToEdge: QSGTexture = ...
        MirroredRepeat: QSGTexture = ...

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qsgtexture.html#QSGTexture

        **QSGTexture::QSGTexture()**

        Constructs the QSGTexture base class.
        """
        ...

    def comparisonKey(self) -> int:
        """
        https://doc.qt.io/qt-6/qsgtexture.html#comparisonKey

        **[pure virtual, since 5.14] qint64 QSGTexture::comparisonKey() const**

        Returns a key suitable for comparing textures. Typically used in
        **QSGMaterial::compare** () implementations.

        Just comparing **QSGTexture**  pointers is not always sufficient because
        two **QSGTexture**  instances that refer to the same native texture
        object underneath should also be considered equal. Hence the need for
        this function.

        Implementations of this function are not expected to, and should not
        create any graphics resources (native texture objects) in case there are
        none yet.

        A **QSGTexture**  that does not have a native texture object underneath
        is typically **not** equal to any other **QSGTexture** , so the return
        value has to be crafted accordingly. There are exceptions to this, in
        particular when atlasing is used (where multiple textures share the same
        atlas texture under the hood), that is then up to the subclass
        implementations to deal with as appropriate.

        **Warning:** This function can only be called from the rendering thread.

        This function was introduced in Qt 5.14.
        """
        ...

    def anisotropyLevel(self) -> "QSGTexture.AnisotropyLevel":
        """
        https://doc.qt.io/qt-6/qsgtexture.html#anisotropyLevel

        **[since 5.9] QSGTexture::AnisotropyLevel QSGTexture::anisotropyLevel()
        const**

        Returns the anisotropy level in use for filtering this texture.

        This function was introduced in Qt 5.9.

        **See also** **setAnisotropyLevel** ().
        """
        ...

    def setAnisotropyLevel(self, level: "QSGTexture.AnisotropyLevel") -> None:
        """
        https://doc.qt.io/qt-6/qsgtexture.html#setAnisotropyLevel

        **[since 5.9] void
        QSGTexture::setAnisotropyLevel(QSGTexture::AnisotropyLevel level )**

        Sets the level of anisotropic filtering to **level**. The default value
        is **QSGTexture::AnisotropyNone** , which means no anisotropic filtering
        is enabled.

        **Note:** The request may be ignored depending on the graphics API in
        use. There is no guarantee anisotropic filtering is supported at run
        time.

        This function was introduced in Qt 5.9.

        **See also** **anisotropyLevel** ().
        """
        ...

    def convertToNormalizedSourceRect(self, rect: QtCore.QRectF) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qsgtexture.html#convertToNormalizedSourceRect

        **QRectF QSGTexture::convertToNormalizedSourceRect(const QRectF & rect )
        const**

        Returns **rect** converted to normalized coordinates.

        **See also** **normalizedTextureSubRect** ().
        """
        ...

    def verticalWrapMode(self) -> "QSGTexture.WrapMode":
        """
        https://doc.qt.io/qt-6/qsgtexture.html#verticalWrapMode

        **QSGTexture::WrapMode QSGTexture::verticalWrapMode() const**

        Returns the vertical wrap mode to be used for this texture.

        **See also** **setVerticalWrapMode** ().
        """
        ...

    def setVerticalWrapMode(self, vwrap: "QSGTexture.WrapMode") -> None:
        """
        https://doc.qt.io/qt-6/qsgtexture.html#setVerticalWrapMode

        **void QSGTexture::setVerticalWrapMode(QSGTexture::WrapMode vwrap )**

        Sets the vertical wrap mode to **vwrap**

        **See also** **verticalWrapMode** ().
        """
        ...

    def horizontalWrapMode(self) -> "QSGTexture.WrapMode":
        """
        https://doc.qt.io/qt-6/qsgtexture.html#horizontalWrapMode

        **QSGTexture::WrapMode QSGTexture::horizontalWrapMode() const**

        Returns the horizontal wrap mode to be used for this texture.

        **See also** **setHorizontalWrapMode** ().
        """
        ...

    def setHorizontalWrapMode(self, hwrap: "QSGTexture.WrapMode") -> None:
        """
        https://doc.qt.io/qt-6/qsgtexture.html#setHorizontalWrapMode

        **void QSGTexture::setHorizontalWrapMode(QSGTexture::WrapMode hwrap )**

        Sets the horizontal wrap mode to **hwrap**

        **See also** **horizontalWrapMode** ().
        """
        ...

    def filtering(self) -> "QSGTexture.Filtering":
        """
        https://doc.qt.io/qt-6/qsgtexture.html#filtering

        **QSGTexture::Filtering QSGTexture::filtering() const**

        Returns the sampling mode to be used for this texture.

        **See also** **setFiltering** ().
        """
        ...

    def setFiltering(self, filter: "QSGTexture.Filtering") -> None:
        """
        https://doc.qt.io/qt-6/qsgtexture.html#setFiltering

        **void QSGTexture::setFiltering(QSGTexture::Filtering filter )**

        Sets the sampling mode to **filter**.

        **See also** **filtering** ().
        """
        ...

    def mipmapFiltering(self) -> "QSGTexture.Filtering":
        """
        https://doc.qt.io/qt-6/qsgtexture.html#mipmapFiltering

        **QSGTexture::Filtering QSGTexture::mipmapFiltering() const**

        Returns whether mipmapping should be used when sampling from this
        texture.

        **See also** **setMipmapFiltering** ().
        """
        ...

    def setMipmapFiltering(self, filter: "QSGTexture.Filtering") -> None:
        """
        https://doc.qt.io/qt-6/qsgtexture.html#setMipmapFiltering

        **void QSGTexture::setMipmapFiltering(QSGTexture::Filtering filter )**

        Sets the mipmap sampling mode to **filter**.

        Setting the mipmap filtering has no effect it the texture does not have
        mipmaps.

        **See also** **mipmapFiltering** () and **hasMipmaps** ().
        """
        ...

    def isAtlasTexture(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsgtexture.html#isAtlasTexture

        **[virtual] bool QSGTexture::isAtlasTexture() const**

        Returns whether this texture is part of an atlas or not.

        The default implementation returns false.
        """
        ...

    def normalizedTextureSubRect(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qsgtexture.html#normalizedTextureSubRect

        **[virtual] QRectF QSGTexture::normalizedTextureSubRect() const**

        Returns the rectangle inside **textureSize** () that this texture
        represents in normalized coordinates.

        The default implementation returns a rect at position (0, 0) with width
        and height of 1.
        """
        ...

    def hasMipmaps(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsgtexture.html#hasMipmaps

        **[pure virtual] bool QSGTexture::hasMipmaps() const**

        Returns true if the texture data contains mipmap levels.
        """
        ...

    def hasAlphaChannel(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsgtexture.html#hasAlphaChannel

        **[pure virtual] bool QSGTexture::hasAlphaChannel() const**

        Returns true if the texture data contains an alpha channel.
        """
        ...

    def textureSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qsgtexture.html#textureSize

        **[pure virtual] QSize QSGTexture::textureSize() const**

        Returns the size of the texture.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtGui import *


class QTextFragment(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qtextfragment.html

    **Detailed Description**

    A text fragment describes a piece of text that is stored with a single
    character format. Text in which the character format changes can be
    represented by sequences of text fragments with different formats.

    If the user edits the text in a fragment and introduces a different
    character format, the fragment's text will be split at each point where the
    format changes, and new fragments will be created. For example, changing the
    style of some text in the middle of a sentence will cause the fragment to be
    broken into three separate fragments: the first and third with the same
    format as before, and the second with the new style. The first fragment will
    contain the text from the beginning of the sentence, the second will contain
    the text from the middle, and the third takes the text from the end of the
    sentence.

    ![](images/qtextfragment-split.png)

    A fragment's text and character format can be obtained with the **text** ()
    and **charFormat** () functions. The **length** () function gives the length
    of the text in the fragment. **position** () gives the position in the
    document of the start of the fragment. To determine whether the fragment
    contains a particular position within the document, use the **contains** ()
    function.

    **See also** **QTextDocument**  and **Rich Text Document Structure** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextfragment.html#QTextFragment-1

        **QTextFragment::QTextFragment()**

        Creates a new empty text fragment.
        """
        ...

    @typing.overload
    def __init__(self, o: "QTextFragment") -> None:
        """
        https://doc.qt.io/qt-6/qtextfragment.html#QTextFragment-2

        **QTextFragment::QTextFragment(const QTextFragment & other )**

        Copies the content (text and format) of the **other** text fragment to
        this text fragment.
        """
        ...

    def glyphRuns(self, from_: int = ..., length: int = ...) -> typing.List[QGlyphRun]:
        """
        https://doc.qt.io/qt-6/qtextfragment.html#glyphRuns

        **QList<QGlyphRun> QTextFragment::glyphRuns(int pos = -1, int len = -1)
        const**

        Returns the glyphs corresponding to **len** characters of this text
        fragment starting at position **pos**. The positions of the glyphs are
        relative to the position of the **QTextBlock** 's layout.

        If **pos** is less than zero, it will default to the start of the
        **QTextFragment** . If **len** is less than zero, it will default to the
        length of the fragment.

        **See also** **QGlyphRun** , **QTextBlock::layout** (),
        **QTextLayout::position** (), and **QPainter::drawGlyphRun** ().
        """
        ...

    def text(self) -> str:
        """
        https://doc.qt.io/qt-6/qtextfragment.html#text

        **QString QTextFragment::text() const**

        Returns the text fragment's as plain text.

        **See also** **length** () and **charFormat** ().
        """
        ...

    def charFormatIndex(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextfragment.html#charFormatIndex

        **int QTextFragment::charFormatIndex() const**

        Returns an index into the document's internal list of character formats
        for the text fragment's character format.

        **See also** **QTextDocument::allFormats** ().
        """
        ...

    def charFormat(self) -> QTextCharFormat:
        """
        https://doc.qt.io/qt-6/qtextfragment.html#charFormat

        **QTextCharFormat QTextFragment::charFormat() const**

        Returns the text fragment's character format.

        **See also** **text** ().
        """
        ...

    def contains(self, position: int) -> bool:
        """
        https://doc.qt.io/qt-6/qtextfragment.html#contains

        **bool QTextFragment::contains(int position ) const**

        Returns `true` if the text fragment contains the text at the given
        **position** in the document; otherwise returns `false`.
        """
        ...

    def length(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextfragment.html#length

        **int QTextFragment::length() const**

        Returns the number of characters in the text fragment.

        **See also** **text** ().
        """
        ...

    def position(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextfragment.html#position

        **int QTextFragment::position() const**

        Returns the position of this text fragment in the document.
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextfragment.html#isValid

        **bool QTextFragment::isValid() const**

        Returns `true` if this is a valid text fragment (i.e. has a valid
        position in a document); otherwise returns `false`.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QCoreApplication(QObject):
    """
    https://doc.qt.io/qt-6/qcoreapplication.html

    **Detailed Description**

    This class is used by non-GUI applications to provide their event loop. For
    non-GUI application that uses Qt, there should be exactly one
    QCoreApplication object. For GUI applications, see **QGuiApplication** . For
    applications that use the Qt Widgets module, see **QApplication** .

    QCoreApplication contains the main event loop, where all events from the
    operating system (e.g., timer and network events) and other sources are
    processed and dispatched. It also handles the application's initialization
    and finalization, as well as system-wide and application-wide settings.

    **The Event Loop and Event Handling**

    The event loop is started with a call to **exec** (). Long-running
    operations can call **processEvents** () to keep the application responsive.

    In general, we recommend that you create a QCoreApplication,
    **QGuiApplication**  or a **QApplication**  object in your `main()` function
    as early as possible. **exec** () will not return until the event loop
    exits; e.g., when **quit** () is called.

    Several static convenience functions are also provided. The QCoreApplication
    object is available from **instance** (). Events can be sent with
    **sendEvent** () or posted to an event queue with **postEvent** (). Pending
    events can be removed with **removePostedEvents** () or dispatched with
    **sendPostedEvents** ().

    The class provides a **quit** () slot and an **aboutToQuit** () signal.

    **Application and Library Paths**

    An application has an **applicationDirPath** () and an
    **applicationFilePath** (). Library paths (see **QLibrary** ) can be
    retrieved with **libraryPaths** () and manipulated by **setLibraryPaths**
    (), **addLibraryPath** (), and **removeLibraryPath** ().

    **Internationalization and Translations**

    Translation files can be added or removed using **installTranslator** () and
    **removeTranslator** (). Application strings can be translated using
    **translate** (). The **QObject::tr** () function is implemented in terms of
    **translate** ().

    **Accessing Command Line Arguments**

    The command line arguments which are passed to QCoreApplication's
    constructor should be accessed using the **arguments** () function.

    **Note:** QCoreApplication removes option `-qmljsdebugger="..."`. It parses
    the argument of `qmljsdebugger`, and then removes this option plus its
    argument.

    For more advanced command line option handling, create a
    **QCommandLineParser** .

    **Locale Settings**

    On Unix/Linux Qt is configured to use the system locale settings by default.
    This can cause a conflict when using POSIX functions, for instance, when
    converting between data types such as floats and strings, since the notation
    may differ between locales. To get around this problem, call the POSIX
    function `setlocale(LC_NUMERIC,"C")` right after initializing
    **QApplication** , **QGuiApplication**  or QCoreApplication to reset the
    locale that is used for number formatting to "C"-locale.

    **See also** **QGuiApplication** , **QAbstractEventDispatcher** ,
    **QEventLoop** , **Semaphores Example** , and **Wait Conditions Example** .
    """

    def __init__(self, argv: typing.List[str]) -> None:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#QCoreApplication

        **QCoreApplication::QCoreApplication(int & argc , char ** argv )**

        Constructs a Qt core application. Core applications are applications
        without a graphical user interface. Such applications are used at the
        console or as server processes.

        The **argc** and **argv** arguments are processed by the application,
        and made available in a more convenient form by the **arguments** ()
        function.

        **Warning:** The data referred to by **argc** and **argv** must stay
        valid for the entire lifetime of the QCoreApplication object. In
        addition, **argc** must be greater than zero and **argv** must contain
        at least one valid character string.
        """
        ...

    def __exit__(
        self, type: typing.Any, value: typing.Any, traceback: typing.Any
    ) -> None:
        ...

    def __enter__(self) -> typing.Any:
        ...

    @staticmethod
    def isSetuidAllowed() -> bool:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#isSetuidAllowed

        **[static, since 5.3] bool QCoreApplication::isSetuidAllowed()**

        Returns true if the application is allowed to run setuid on UNIX
        platforms.

        This function was introduced in Qt 5.3.

        **See also** **QCoreApplication::setSetuidAllowed** ().
        """
        ...

    @staticmethod
    def setSetuidAllowed(allow: bool) -> None:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#setSetuidAllowed

        **[static, since 5.3] void QCoreApplication::setSetuidAllowed(bool allow
        )**

        Allows the application to run setuid on UNIX platforms if **allow** is
        true.

        If **allow** is false (the default) and Qt detects the application is
        running with an effective user id different than the real user id, the
        application will be aborted when a **QCoreApplication**  instance is
        created.

        Qt is not an appropriate solution for setuid programs due to its large
        attack surface. However some applications may be required to run in this
        manner for historical reasons. This flag will prevent Qt from aborting
        the application when this is detected, and must be set before a
        **QCoreApplication**  instance is created.

        **Note:** It is strongly recommended not to enable this option since it
        introduces security risks.

        This function was introduced in Qt 5.3.

        **See also** **isSetuidAllowed** ().
        """
        ...

    def removeNativeEventFilter(self, filterObj: QAbstractNativeEventFilter) -> None:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#removeNativeEventFilter

        **[since 5.0] void
        QCoreApplication::removeNativeEventFilter(QAbstractNativeEventFilter *
        filterObject )**

        Removes an event **filterObject** from this object. The request is
        ignored if such an event filter has not been installed.

        All event filters for this object are automatically removed when this
        object is destroyed.

        It is always safe to remove an event filter, even during event filter
        activation (i.e. from the nativeEventFilter() function).

        This function was introduced in Qt 5.0.

        **See also** **installNativeEventFilter** ().
        """
        ...

    def installNativeEventFilter(self, filterObj: QAbstractNativeEventFilter) -> None:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#installNativeEventFilter

        **[since 5.0] void
        QCoreApplication::installNativeEventFilter(QAbstractNativeEventFilter *
        filterObj )**

        Installs an event filter **filterObj** for all native events received by
        the application in the main thread.

        The event filter **filterObj** receives events via its
        **nativeEventFilter** () function, which is called for all native events
        received in the main thread.

        The **QAbstractNativeEventFilter::nativeEventFilter** () function should
        return true if the event should be filtered, i.e. stopped. It should
        return false to allow normal Qt processing to continue: the native event
        can then be translated into a **QEvent**  and handled by the standard Qt
        **event**  filtering, e.g. **QObject::installEventFilter** ().

        If multiple event filters are installed, the filter that was installed
        last is activated first.

        **Note:** The filter function set here receives native messages, i.e.
        MSG or XCB event structs.

        **Note:** Native event filters will be disabled in the application when
        the **Qt::AA_PluginApplication**  attribute is set.

        For maximum portability, you should always try to use **QEvent**  and
        **QObject::installEventFilter** () whenever possible.

        This function was introduced in Qt 5.0.

        **See also** **QObject::installEventFilter** ().
        """
        ...

    @staticmethod
    def setQuitLockEnabled(enabled: bool) -> None:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#quitLockEnabled-prop

        **quitLockEnabled : bool**

        This property holds whether the use of the **QEventLoopLocker**  feature
        can cause the application to quit.

        The default is `true`.

        **Access functions:**

        bool **isQuitLockEnabled** ()
        void **setQuitLockEnabled** (bool
        **enabled** )

        **See also** **QEventLoopLocker** .

        **Member Function Documentation**
        """
        ...

    @staticmethod
    def isQuitLockEnabled() -> bool:
        ...

    @staticmethod
    def setEventDispatcher(eventDispatcher: QAbstractEventDispatcher) -> None:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#setEventDispatcher

        **[static] void
        QCoreApplication::setEventDispatcher(QAbstractEventDispatcher *
        eventDispatcher )**

        Sets the event dispatcher for the main thread to **eventDispatcher**.
        This is only possible as long as there is no event dispatcher installed
        yet. That is, before **QCoreApplication**  has been instantiated. This
        method takes ownership of the object.

        **See also** **eventDispatcher** ().
        """
        ...

    @staticmethod
    def eventDispatcher() -> QAbstractEventDispatcher:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#eventDispatcher

        **[static] QAbstractEventDispatcher
        *QCoreApplication::eventDispatcher()**

        Returns a pointer to the event dispatcher object for the main thread. If
        no event dispatcher exists for the thread, this function returns
        `nullptr`.

        **See also** **setEventDispatcher** ().
        """
        ...

    @staticmethod
    def applicationPid() -> int:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#applicationPid

        **[static] qint64 QCoreApplication::applicationPid()**

        Returns the current process ID for the application.
        """
        ...

    @staticmethod
    def applicationVersion() -> str:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#applicationVersion-prop

        **applicationVersion : QString**

        This property holds the version of this application

        If not set, the application version defaults to a platform-specific
        value determined from the main application executable or package (since
        Qt 5.9):

        PlatformSource
        Windows (classic desktop)PRODUCTVERSION parameter of
        the VERSIONINFO resource
        macOS, iOS, tvOS, watchOSCFBundleVersion
        property of the information property list
        Androidandroid:versionName
        property of the AndroidManifest.xml manifest element

        On other platforms, the default is the empty string.

        **Access functions:**

        QString **applicationVersion** ()
        void **setApplicationVersion**
        (const QString & **version** )

        **Notifier signal:**

        void **applicationVersionChanged** ()

        **See also** **applicationName** , **organizationName** , and
        **organizationDomain** .
        """
        ...

    @staticmethod
    def setApplicationVersion(version: str) -> None:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#applicationVersion-prop

        **applicationVersion : QString**

        This property holds the version of this application

        If not set, the application version defaults to a platform-specific
        value determined from the main application executable or package (since
        Qt 5.9):

        PlatformSource
        Windows (classic desktop)PRODUCTVERSION parameter of
        the VERSIONINFO resource
        macOS, iOS, tvOS, watchOSCFBundleVersion
        property of the information property list
        Androidandroid:versionName
        property of the AndroidManifest.xml manifest element

        On other platforms, the default is the empty string.

        **Access functions:**

        QString **applicationVersion** ()
        void **setApplicationVersion**
        (const QString & **version** )

        **Notifier signal:**

        void **applicationVersionChanged** ()

        **See also** **applicationName** , **organizationName** , and
        **organizationDomain** .
        """
        ...

    def event(self, a0: "QEvent") -> bool:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#event

        **[override virtual protected] bool QCoreApplication::event(QEvent * e
        )**

        Reimplements: **QObject::event** (QEvent *e).
        """
        ...

    @staticmethod
    def exit(returnCode: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#exit

        **[static slot] void QCoreApplication::exit(int returnCode = 0)**

        Tells the application to exit with a return code.

        After this function has been called, the application leaves the main
        event loop and returns from the call to **exec** (). The **exec** ()
        function returns **returnCode**. If the event loop is not running, this
        function does nothing.

        By convention, a **returnCode** of 0 means success, and any non-zero
        value indicates an error.

        It's good practice to always connect signals to this slot using a
        **QueuedConnection** . If a signal connected (non-queued) to this slot
        is emitted before control enters the main event loop (such as before
        "int main" calls **exec** ()), the slot has no effect and the
        application never exits. Using a queued connection ensures that the slot
        will not be invoked until after control enters the main event loop.

        Note that unlike the C library function of the same name, this function
        **does** return to the caller -- it is event processing that stops.

        Note also that this function is not thread-safe. It should be called
        only from the main thread (the thread that the **QCoreApplication**
        object is processing events on). To ask the application to exit from
        another thread, either use **QCoreApplication::quit** () or instead call
        this function from the main thread with QMetaMethod::invokeMethod().

        **See also** **quit** () and **exec** ().
        """
        ...

    @staticmethod
    def quit() -> None:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#quit

        **[static slot] void QCoreApplication::quit()**

        Asks the application to quit.

        The request may be ignored if the application prevents the quit, for
        example if one of its windows can't be closed. The application can
        affect this by handling the **QEvent::Quit**  event on the application
        level, or **QEvent::Close**  events for the individual windows.

        If the quit is not interrupted the application will exit with return
        code 0 (success).

        To exit the application without a chance of being interrupted, call
        **exit** () directly. Note that method is not thread-safe.

        It's good practice to always connect signals to this slot using a
        **QueuedConnection** . If a signal connected (non-queued) to this slot
        is emitted before control enters the main event loop (such as before
        "int main" calls **exec** ()), the slot has no effect and the
        application never exits. Using a queued connection ensures that the slot
        will not be invoked until after control enters the main event loop.

        Example:

        **QPushButton**  *quitButton = new **QPushButton** ("Quit");
        connect(quitButton, &**QPushButton** ::clicked, &app,
        &**QCoreApplication** ::quit, Qt::QueuedConnection);

        **Thread-safety note** : this function may be called from any thread to
        thread-safely cause the currently-running main application loop to exit.
        However, thread-safety is not guaranteed if the **QCoreApplication**
        object is being destroyed at the same time.

        **Note:** This function is **thread-safe** .

        **See also** **exit** () and **aboutToQuit** ().
        """
        ...

    @staticmethod
    def testAttribute(attribute: Qt.ApplicationAttribute) -> bool:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#testAttribute

        **[static] bool QCoreApplication::testAttribute(Qt::ApplicationAttribute
        attribute )**

        Returns `true` if attribute **attribute** is set; otherwise returns
        `false`.

        **See also** **setAttribute** ().
        """
        ...

    @staticmethod
    def setAttribute(attribute: Qt.ApplicationAttribute, on: bool = ...) -> None:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#setAttribute

        **[static] void QCoreApplication::setAttribute(Qt::ApplicationAttribute
        attribute , bool on = true)**

        Sets the attribute **attribute** if **on** is true; otherwise clears the
        attribute.

        **Note:** Some application attributes must be set **before** creating a
        **QCoreApplication**  instance. Refer to the
        **Qt::ApplicationAttribute**  documentation for more information.

        **See also** **testAttribute** ().
        """
        ...

    @staticmethod
    def translate(
        context: str,
        sourceText: str,
        disambiguation: typing.Optional[str] = ...,
        n: int = ...,
    ) -> str:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#translate

        **[static] QString QCoreApplication::translate(const char * context ,
        const char * sourceText , const char * disambiguation = nullptr, int n =
        -1)**

        Returns the translation text for **sourceText** , by querying the
        installed translation files. The translation files are searched from the
        most recently installed file back to the first installed file.

        **QObject::tr** () provides this functionality more conveniently.

        **context** is typically a class name (e.g., "MyDialog") and
        **sourceText** is either English text or a short identifying text.

        **disambiguation** is an identifying string, for when the same
        **sourceText** is used in different roles within the same context. By
        default, it is `nullptr`.

        See the **QTranslator**  and **QObject::tr** () documentation for more
        information about contexts, disambiguations and comments.

        **n** is used in conjunction with `%n` to support plural forms. See
        **QObject::tr** () for details.

        If none of the translation files contain a translation for
        **sourceText** in **context** , this function returns a **QString**
        equivalent of **sourceText**.

        This function is not virtual. You can use alternative translation
        techniques by subclassing **QTranslator** .

        **Note:** This function is **thread-safe** .

        **See also** **QObject::tr** (), **installTranslator** (),
        **removeTranslator** (), and translate().
        """
        ...

    @staticmethod
    def removeTranslator(messageFile: "QTranslator") -> bool:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#removeTranslator

        **[static] bool QCoreApplication::removeTranslator(QTranslator *
        translationFile )**

        Removes the translation file **translationFile** from the list of
        translation files used by this application. (It does not delete the
        translation file from the file system.)

        The function returns `true` on success and false on failure.

        **See also** **installTranslator** (), **translate** (), and
        **QObject::tr** ().
        """
        ...

    @staticmethod
    def installTranslator(messageFile: "QTranslator") -> bool:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#installTranslator

        **[static] bool QCoreApplication::installTranslator(QTranslator *
        translationFile )**

        Adds the translation file **translationFile** to the list of translation
        files to be used for translations.

        Multiple translation files can be installed. Translations are searched
        for in the reverse order in which they were installed, so the most
        recently installed translation file is searched first and the first
        translation file installed is searched last. The search stops as soon as
        a translation containing a matching string is found.

        Installing or removing a **QTranslator** , or changing an installed
        **QTranslator**  generates a **LanguageChange**  event for the
        **QCoreApplication**  instance. A **QApplication**  instance will
        propagate the event to all toplevel widgets, where a reimplementation of
        changeEvent can re-translate the user interface by passing user-visible
        strings via the **tr** () function to the respective property setters.
        User-interface classes generated by Qt Designer provide a
        `retranslateUi()` function that can be called.

        The function returns `true` on success and false on failure.

        **See also** **removeTranslator** (), **translate** (),
        **QTranslator::load** (), and **Dynamic Translation** .
        """
        ...

    @staticmethod
    def removeLibraryPath(a0: str) -> None:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#removeLibraryPath

        **[static] void QCoreApplication::removeLibraryPath(const QString & path
        )**

        Removes **path** from the library path list. If **path** is empty or not
        in the path list, the list is not changed.

        The library paths are reset to the default when an instance of
        **QCoreApplication**  is destructed.

        **See also** **addLibraryPath** (), **libraryPaths** (), and
        **setLibraryPaths** ().
        """
        ...

    @staticmethod
    def addLibraryPath(a0: str) -> None:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#addLibraryPath

        **[static] void QCoreApplication::addLibraryPath(const QString & path
        )**

        Prepends **path** to the beginning of the library path list, ensuring
        that it is searched for libraries first. If **path** is empty or already
        in the path list, the path list is not changed.

        The default path list consists of one or two entries. The first is the
        installation directory for plugins, which is `INSTALL/plugins`, where
        `INSTALL` is the directory where Qt was installed. The second is the
        application's own directory ( **not** the current directory), but only
        after the **QCoreApplication**  object is instantiated.

        The library paths are reset to the default when an instance of
        **QCoreApplication**  is destructed.

        **See also** **removeLibraryPath** (), **libraryPaths** (), and
        **setLibraryPaths** ().
        """
        ...

    @staticmethod
    def libraryPaths() -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#libraryPaths

        **[static] QStringList QCoreApplication::libraryPaths()**

        Returns a list of paths that the application will search when
        dynamically loading libraries.

        The return value of this function may change when a **QCoreApplication**
        is created. It is not recommended to call it before creating a
        **QCoreApplication** . The directory of the application executable (
        **not** the working directory) is part of the list if it is known. In
        order to make it known a **QCoreApplication**  has to be constructed as
        it will use `argv[0]` to find it.

        Qt provides default library paths, but they can also be set using a
        **qt.conf**  file. Paths specified in this file will override default
        values. Note that if the qt.conf file is in the directory of the
        application executable, it may not be found until a **QCoreApplication**
        is created. If it is not found when calling this function, the default
        library paths will be used.

        The list will include the installation directory for plugins if it
        exists (the default installation directory for plugins is
        `INSTALL/plugins`, where `INSTALL` is the directory where Qt was
        installed). The colon separated entries of the `QT_PLUGIN_PATH`
        environment variable are always added. The plugin installation directory
        (and its existence) may change when the directory of the application
        executable becomes known.

        If you want to iterate over the list, you can use the **foreach**
        pseudo-keyword:

        foreach (const **QString**  &path, app.libraryPaths())
        do_something(path);

        **See also** **setLibraryPaths** (), **addLibraryPath** (),
        **removeLibraryPath** (), **QLibrary** , and **How to Create Qt
        Plugins** .
        """
        ...

    @staticmethod
    def setLibraryPaths(a0: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#setLibraryPaths

        **[static] void QCoreApplication::setLibraryPaths(const QStringList &
        paths )**

        Sets the list of directories to search when loading plugins with
        **QLibrary**  to **paths**. All existing paths will be deleted and the
        path list will consist of the paths given in **paths** and the path to
        the application.

        The library paths are reset to the default when an instance of
        **QCoreApplication**  is destructed.

        **See also** **libraryPaths** (), **addLibraryPath** (),
        **removeLibraryPath** (), and **QLibrary** .
        """
        ...

    @staticmethod
    def applicationFilePath() -> str:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#applicationFilePath

        **[static] QString QCoreApplication::applicationFilePath()**

        Returns the file path of the application executable.

        For example, if you have installed Qt in the `/usr/local/qt` directory,
        and you run the `regexp` example, this function will return
        "/usr/local/qt/examples/tools/regexp/regexp".

        **Warning:** On Linux, this function will try to get the path from the
        `/proc` file system. If that fails, it assumes that `argv[0]` contains
        the absolute file name of the executable. The function also assumes that
        the current directory has not been changed by the application.

        **See also** **applicationDirPath** ().
        """
        ...

    @staticmethod
    def applicationDirPath() -> str:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#applicationDirPath

        **[static] QString QCoreApplication::applicationDirPath()**

        Returns the directory that contains the application executable.

        For example, if you have installed Qt in the `C:\\Qt` directory, and you
        run the `regexp` example, this function will return
        "C:/Qt/examples/tools/regexp".

        On macOS and iOS this will point to the directory actually containing
        the executable, which may be inside an application bundle (if the
        application is bundled).

        **Warning:** On Linux, this function will try to get the path from the
        `/proc` file system. If that fails, it assumes that `argv[0]` contains
        the absolute file name of the executable. The function also assumes that
        the current directory has not been changed by the application.

        **See also** **applicationFilePath** ().
        """
        ...

    @staticmethod
    def closingDown() -> bool:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#closingDown

        **[static] bool QCoreApplication::closingDown()**

        Returns `true` if the application objects are being destroyed; otherwise
        returns `false`.

        **See also** **startingUp** ().
        """
        ...

    @staticmethod
    def startingUp() -> bool:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#startingUp

        **[static] bool QCoreApplication::startingUp()**

        Returns `true` if an application object has not been created yet;
        otherwise returns `false`.

        **See also** **closingDown** ().
        """
        ...

    def notify(self, a0: QObject, a1: "QEvent") -> bool:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#notify

        **[virtual] bool QCoreApplication::notify(QObject * receiver , QEvent *
        event )**

        Sends **event** to **receiver** : **receiver** ->event( **event** ).
        Returns the value that is returned from the receiver's event handler.
        Note that this function is called for all events sent to any object in
        any thread.

        For certain types of events (e.g. mouse and key events), the event will
        be propagated to the receiver's parent and so on up to the top-level
        object if the receiver is not interested in the event (i.e., it returns
        `false`).

        There are five different ways that events can be processed;
        reimplementing this virtual function is just one of them. All five
        approaches are listed below:

        1. Reimplementing **paintEvent** (), **mousePressEvent** () and so on.
        This is the most common, easiest, and least powerful way.
          2.
        Reimplementing this function. This is very powerful, providing complete
        control; but only one subclass can be active at a time.
          3. Installing
        an event filter on **QCoreApplication::instance** (). Such an event
        filter is able to process all events for all widgets, so it's just as
        powerful as reimplementing notify(); furthermore, it's possible to have
        more than one application-global event filter. Global event filters even
        see mouse events for **disabled widgets** . Note that application event
        filters are only called for objects that live in the main thread.
          4.
        Reimplementing **QObject::event** () (as **QWidget**  does). If you do
        this you get Tab key presses, and you get to see the events before any
        widget-specific event filters.
          5. Installing an event filter on the
        object. Such an event filter gets all the events, including Tab and
        Shift+Tab key press events, as long as they do not change the focus
        widget.

        **Future direction:** This function will not be called for objects that
        live outside the main thread in Qt 6. Applications that need that
        functionality should find other solutions for their event inspection
        needs in the meantime. The change may be extended to the main thread,
        causing this function to be deprecated.

        **Warning:** If you override this function, you must ensure all threads
        that process events stop doing so before your application object begins
        destruction. This includes threads started by other libraries that you
        may be using, but does not apply to Qt's own threads.

        **See also** **QObject::event** () and **installNativeEventFilter** ().
        """
        ...

    @staticmethod
    def removePostedEvents(receiver: QObject, eventType: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#removePostedEvents

        **[static] void QCoreApplication::removePostedEvents(QObject * receiver
        , int eventType = 0)**

        Removes all events of the given **eventType** that were posted using
        **postEvent** () for **receiver**.

        The events are **not** dispatched, instead they are removed from the
        queue. You should never need to call this function. If you do call it,
        be aware that killing events may cause **receiver** to break one or more
        invariants.

        If **receiver** is `nullptr`, the events of **eventType** are removed
        for all objects. If **eventType** is 0, all the events are removed for
        **receiver**. You should never call this function with **eventType** of
        0.

        **Note:** This function is **thread-safe** .
        """
        ...

    @staticmethod
    def sendPostedEvents(
        receiver: typing.Optional[QObject] = ..., eventType: int = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#sendPostedEvents

        **[static] void QCoreApplication::sendPostedEvents(QObject * receiver =
        nullptr, int event_type = 0)**

        Immediately dispatches all events which have been previously queued with
        **QCoreApplication::postEvent** () and which are for the object
        **receiver** and have the event type **event_type**.

        Events from the window system are **not** dispatched by this function,
        but by **processEvents** ().

        If **receiver** is `nullptr`, the events of **event_type** are sent for
        all objects. If **event_type** is 0, all the events are sent for
        **receiver**.

        **Note:** This method must be called from the thread in which its
        **QObject**  parameter, **receiver** , lives.

        **See also** **postEvent** ().
        """
        ...

    @staticmethod
    def postEvent(receiver: QObject, event: "QEvent", priority: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#postEvent

        **[static] void QCoreApplication::postEvent(QObject * receiver , QEvent
        * event , int priority = Qt::NormalEventPriority)**

        Adds the event **event** , with the object **receiver** as the receiver
        of the event, to an event queue and returns immediately.

        The event must be allocated on the heap since the post event queue will
        take ownership of the event and delete it once it has been posted. It is
        **not safe** to access the event after it has been posted.

        When control returns to the main event loop, all events that are stored
        in the queue will be sent using the **notify** () function.

        Events are sorted in descending **priority** order, i.e. events with a
        high **priority** are queued before events with a lower **priority**.
        The **priority** can be any integer value, i.e. between INT_MAX and
        INT_MIN, inclusive; see **Qt::EventPriority**  for more details. Events
        with equal **priority** will be processed in the order posted.

        **Note:** This function is **thread-safe** .

        **See also** **sendEvent** (), **notify** (), **sendPostedEvents** (),
        and **Qt::EventPriority** .
        """
        ...

    @staticmethod
    def sendEvent(receiver: QObject, event: "QEvent") -> bool:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#sendEvent

        **[static] bool QCoreApplication::sendEvent(QObject * receiver , QEvent
        * event )**

        Sends event **event** directly to receiver **receiver** , using the
        **notify** () function. Returns the value that was returned from the
        event handler.

        The event is **not** deleted when the event has been sent. The normal
        approach is to create the event on the stack, for example:

        **QMouseEvent**  event(**QEvent** ::MouseButtonPress, pos, 0, 0, 0);
        **QApplication** ::sendEvent(mainWindow, &event);

        **See also** **postEvent** () and **notify** ().
        """
        ...

    @typing.overload
    @staticmethod
    def processEvents(flags: "QEventLoop.ProcessEventsFlag" = ...) -> None:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#processEvents

        **[static] void
        QCoreApplication::processEvents(QEventLoop::ProcessEventsFlags flags =
        QEventLoop::AllEvents)**

        Processes some pending events for the calling thread according to the
        specified **flags**.

        Use of this function is discouraged. Instead, prefer to move long
        operations out of the GUI thread into an auxiliary one and to completely
        avoid nested event loop processing. If event processing is really
        necessary, consider using **QEventLoop**  instead.

        In the event that you are running a local loop which calls this function
        continuously, without an event loop, the **DeferredDelete**  events will
        not be processed. This can affect the behaviour of widgets, e.g.
        **QToolTip** , that rely on **DeferredDelete**  events to function
        properly. An alternative would be to call **sendPostedEvents** () from
        within that local loop.

        Calling this function processes events only for the calling thread, and
        returns after all available events have been processed. Available events
        are events queued before the function call. This means that events that
        are posted while the function runs will be queued until a later round of
        event processing.

        **Note:** This function is **thread-safe** .

        **See also** **exec** (), **QTimer** , **QEventLoop::processEvents** (),
        and **sendPostedEvents** ().
        """
        ...

    @typing.overload
    @staticmethod
    def processEvents(flags: "QEventLoop.ProcessEventsFlag", maxtime: int) -> None:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#processEvents-1

        **[static] void
        QCoreApplication::processEvents(QEventLoop::ProcessEventsFlags flags ,
        int ms )**

        This function overloads processEvents().

        Processes pending events for the calling thread for **ms** milliseconds
        or until there are no more events to process, whichever is shorter.

        Use of this function is discouraged. Instead, prefer to move long
        operations out of the GUI thread into an auxiliary one and to completely
        avoid nested event loop processing. If event processing is really
        necessary, consider using **QEventLoop**  instead.

        Calling this function processes events only for the calling thread.

        **Note:** Unlike the **processEvents** () overload, this function also
        processes events that are posted while the function runs.

        **Note:** All events that were queued before the timeout will be
        processed, however long it takes.

        **Note:** This function is **thread-safe** .

        **See also** **exec** (), **QTimer** , and **QEventLoop::processEvents**
        ().
        """
        ...

    @staticmethod
    def exec() -> int:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#exec

        **[static] int QCoreApplication::exec()**

        Enters the main event loop and waits until **exit** () is called.
        Returns the value that was passed to **exit** () (which is 0 if **exit**
        () is called via **quit** ()).

        It is necessary to call this function to start event handling. The main
        event loop receives events from the window system and dispatches these
        to the application widgets.

        To make your application perform idle processing (by executing a special
        function whenever there are no pending events), use a **QTimer**  with 0
        timeout. More advanced idle processing schemes can be achieved using
        **processEvents** ().

        We recommend that you connect clean-up code to the **aboutToQuit** ()
        signal, instead of putting it in your application's `main()` function
        because on some platforms the exec() call may not return. For example,
        on Windows when the user logs off, the system terminates the process
        after Qt closes all top-level windows. Hence, there is no guarantee that
        the application will have time to exit its event loop and execute code
        at the end of the `main()` function after the exec() call.

        **See also** **quit** (), **exit** (), **processEvents** (), and
        **QApplication::exec** ().
        """
        ...

    @staticmethod
    def instance() -> "QCoreApplication":
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#instance

        **[static] QCoreApplication *QCoreApplication::instance()**

        Returns a pointer to the application's **QCoreApplication**  (or
        **QGuiApplication** /**QApplication** ) instance.

        If no instance has been allocated, `nullptr` is returned.
        """
        ...

    @staticmethod
    def arguments() -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#arguments

        **[static] QStringList QCoreApplication::arguments()**

        Returns the list of command-line arguments.

        Usually arguments().at(0) is the program name, arguments().at(1) is the
        first argument, and arguments().last() is the last argument. See the
        note below about Windows.

        Calling this function is slow - you should store the result in a
        variable when parsing the command line.

        **Warning:** On Unix, this list is built from the argc and argv
        parameters passed to the constructor in the main() function. The string-
        data in argv is interpreted using **QString::fromLocal8Bit** (); hence
        it is not possible to pass, for example, Japanese command line arguments
        on a system that runs in a Latin1 locale. Most modern Unix systems do
        not have this limitation, as they are Unicode-based.

        On Windows, the list is built from the argc and argv parameters only if
        modified argv/argc parameters are passed to the constructor. In that
        case, encoding problems might occur.

        Otherwise, the arguments() are constructed from the return value of
        **GetCommandLine()** . As a result of this, the string given by
        arguments().at(0) might not be the program name on Windows, depending on
        how the application was started.

        **See also** **applicationFilePath** () and **QCommandLineParser** .
        """
        ...

    @staticmethod
    def applicationName() -> str:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#applicationName-prop

        **applicationName : QString**

        This property holds the name of this application

        The value is used by the **QSettings**  class when it is constructed
        using the empty constructor. This saves having to repeat this
        information each time a **QSettings**  object is created.

        If not set, the application name defaults to the executable name (since
        5.0).

        **Access functions:**

        QString **applicationName** ()
        void **setApplicationName** (const
        QString & **application** )

        **Notifier signal:**

        void **applicationNameChanged** ()

        **See also** **organizationName** , **organizationDomain** ,
        **applicationVersion** , and **applicationFilePath** ().
        """
        ...

    @staticmethod
    def setApplicationName(application: str) -> None:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#applicationName-prop

        **applicationName : QString**

        This property holds the name of this application

        The value is used by the **QSettings**  class when it is constructed
        using the empty constructor. This saves having to repeat this
        information each time a **QSettings**  object is created.

        If not set, the application name defaults to the executable name (since
        5.0).

        **Access functions:**

        QString **applicationName** ()
        void **setApplicationName** (const
        QString & **application** )

        **Notifier signal:**

        void **applicationNameChanged** ()

        **See also** **organizationName** , **organizationDomain** ,
        **applicationVersion** , and **applicationFilePath** ().
        """
        ...

    @staticmethod
    def organizationName() -> str:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#organizationName-prop

        **organizationName : QString**

        This property holds the name of the organization that wrote this
        application

        The value is used by the **QSettings**  class when it is constructed
        using the empty constructor. This saves having to repeat this
        information each time a **QSettings**  object is created.

        On Mac, **QSettings**  uses **organizationDomain** () as the
        organization if it's not an empty string; otherwise it uses
        organizationName(). On all other platforms, **QSettings**  uses
        organizationName() as the organization.

        **Access functions:**

        QString **organizationName** ()
        void **setOrganizationName** (const
        QString & **orgName** )

        **Notifier signal:**

        void **organizationNameChanged** ()

        **See also** **organizationDomain**  and **applicationName** .
        """
        ...

    @staticmethod
    def setOrganizationName(orgName: str) -> None:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#organizationName-prop

        **organizationName : QString**

        This property holds the name of the organization that wrote this
        application

        The value is used by the **QSettings**  class when it is constructed
        using the empty constructor. This saves having to repeat this
        information each time a **QSettings**  object is created.

        On Mac, **QSettings**  uses **organizationDomain** () as the
        organization if it's not an empty string; otherwise it uses
        organizationName(). On all other platforms, **QSettings**  uses
        organizationName() as the organization.

        **Access functions:**

        QString **organizationName** ()
        void **setOrganizationName** (const
        QString & **orgName** )

        **Notifier signal:**

        void **organizationNameChanged** ()

        **See also** **organizationDomain**  and **applicationName** .
        """
        ...

    @staticmethod
    def organizationDomain() -> str:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#organizationDomain-prop

        **organizationDomain : QString**

        This property holds the Internet domain of the organization that wrote
        this application

        The value is used by the **QSettings**  class when it is constructed
        using the empty constructor. This saves having to repeat this
        information each time a **QSettings**  object is created.

        On Mac, **QSettings**  uses organizationDomain() as the organization if
        it's not an empty string; otherwise it uses **organizationName** (). On
        all other platforms, **QSettings**  uses **organizationName** () as the
        organization.

        **Access functions:**

        QString **organizationDomain** ()
        void **setOrganizationDomain**
        (const QString & **orgDomain** )

        **Notifier signal:**

        void **organizationDomainChanged** ()

        **See also** **organizationName** , **applicationName** , and
        **applicationVersion** .
        """
        ...

    @staticmethod
    def setOrganizationDomain(orgDomain: str) -> None:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#organizationDomain-prop

        **organizationDomain : QString**

        This property holds the Internet domain of the organization that wrote
        this application

        The value is used by the **QSettings**  class when it is constructed
        using the empty constructor. This saves having to repeat this
        information each time a **QSettings**  object is created.

        On Mac, **QSettings**  uses organizationDomain() as the organization if
        it's not an empty string; otherwise it uses **organizationName** (). On
        all other platforms, **QSettings**  uses **organizationName** () as the
        organization.

        **Access functions:**

        QString **organizationDomain** ()
        void **setOrganizationDomain**
        (const QString & **orgDomain** )

        **Notifier signal:**

        void **organizationDomainChanged** ()

        **See also** **organizationName** , **applicationName** , and
        **applicationVersion** .
        """
        ...

    @property
    def aboutToQuit(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qcoreapplication.html#aboutToQuit

        **[private signal] void QCoreApplication::aboutToQuit()**

        This signal is emitted when the application is about to quit the main
        event loop, e.g. when the event loop level drops to zero. This may
        happen either after a call to **quit** () from inside the application or
        when the user shuts down the entire desktop session.

        The signal is particularly useful if your application has to do some
        last-second cleanup. Note that no user interaction is possible in this
        state.

        **Note:** This is a private signal. It can be used in signal connections
        but cannot be emitted by the user.

        **See also** **quit** ().
        """
        ...

    @property
    def applicationNameChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def applicationVersionChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def organizationDomainChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def organizationNameChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QSinglePointEvent(QPointerEvent):
    """
    https://doc.qt.io/qt-6/qsinglepointevent.html

    **Detailed Description**
    """

    def clone(self) -> "QSinglePointEvent":
        ...

    def setExclusivePointGrabber(self, exclusiveGrabber: QtCore.QObject) -> None:
        """
        https://doc.qt.io/qt-6/qsinglepointevent.html#exclusivePointGrabber-prop

        **exclusivePointGrabber : QObject***

        This property holds the object that will receive future updates

        The exclusive grabber is an object that has chosen to receive all future
        update events and the release event containing the same point that this
        event carries.

        Setting the exclusivePointGrabber property is a convenience equivalent
        to:

        setExclusiveGrabber(points().first(), exclusiveGrabber);

        **Access functions:**

        QObject * **exclusivePointGrabber** () const
        void
        **setExclusivePointGrabber** (QObject * **exclusiveGrabber** )

        **Member Function Documentation**
        """
        ...

    def exclusivePointGrabber(self) -> QtCore.QObject:
        """
        https://doc.qt.io/qt-6/qsinglepointevent.html#exclusivePointGrabber-prop

        **exclusivePointGrabber : QObject***

        This property holds the object that will receive future updates

        The exclusive grabber is an object that has chosen to receive all future
        update events and the release event containing the same point that this
        event carries.

        Setting the exclusivePointGrabber property is a convenience equivalent
        to:

        setExclusiveGrabber(points().first(), exclusiveGrabber);

        **Access functions:**

        QObject * **exclusivePointGrabber** () const
        void
        **setExclusivePointGrabber** (QObject * **exclusiveGrabber** )

        **Member Function Documentation**
        """
        ...

    def isEndEvent(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsinglepointevent.html#isEndEvent

        **[override virtual] bool QSinglePointEvent::isEndEvent() const**

        Returns `true` if this event represents a **button**  being released.
        """
        ...

    def isUpdateEvent(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsinglepointevent.html#isUpdateEvent

        **[override virtual] bool QSinglePointEvent::isUpdateEvent() const**

        Returns `true` if this event does not include a change in **button
        state** .
        """
        ...

    def isBeginEvent(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsinglepointevent.html#isBeginEvent

        **[override virtual] bool QSinglePointEvent::isBeginEvent() const**

        Returns `true` if this event represents a **button**  being pressed.
        """
        ...

    def globalPosition(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qsinglepointevent.html#globalPosition

        **QPointF QSinglePointEvent::globalPosition() const**

        Returns the position of the point in this event on the screen or virtual
        desktop.

        **Note:** The global position of a mouse pointer is recorded **at the
        time of the event**. This is important on asynchronous window systems
        such as X11; whenever you move your widgets around in response to mouse
        events, globalPosition() can differ a lot from the current cursor
        position returned by **QCursor::pos** ().

        **See also** **position** ().
        """
        ...

    def scenePosition(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qsinglepointevent.html#scenePosition

        **QPointF QSinglePointEvent::scenePosition() const**

        Returns the position of the point in this event, relative to the window
        or scene.

        **See also** **QEventPoint::scenePosition** .
        """
        ...

    def position(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qsinglepointevent.html#position

        **QPointF QSinglePointEvent::position() const**

        Returns the position of the point in this event, relative to the widget
        or item that received the event.

        If you move your widgets around in response to mouse events, use
        **globalPosition** () instead.

        **See also** **globalPosition** ().
        """
        ...

    def buttons(self) -> QtCore.Qt.MouseButton:
        """
        https://doc.qt.io/qt-6/qsinglepointevent.html#buttons

        **Qt::MouseButtons QSinglePointEvent::buttons() const**

        Returns the button state when the event was generated.

        The button state is a combination of **Qt::LeftButton** ,
        **Qt::RightButton** , and **Qt::MiddleButton**  using the OR operator.

        For mouse move or **TabletMove**  events, this is all buttons that are
        pressed down.

        For mouse press, double click, or **TabletPress**  events, this includes
        the button that caused the event.

        For mouse release or **TabletRelease**  events, this excludes the button
        that caused the event.

        **See also** **button** ().
        """
        ...

    def button(self) -> QtCore.Qt.MouseButton:
        """
        https://doc.qt.io/qt-6/qsinglepointevent.html#button

        **Qt::MouseButton QSinglePointEvent::button() const**

        Returns the button that caused the event.

        The returned value is always **Qt::NoButton**  for mouse move events, as
        well as **TabletMove** , **TabletEnterProximity** , and
        **TabletLeaveProximity**  events.

        **See also** **buttons** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtQuick import *


class QNativeInterface(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qnativeinterface.html

    **Detailed Description**

    For documentation on how to use these interfaces, see the **Native
    Interfaces**  overview.

    **Warning:** There are no source or binary compatibility guarantees for the
    native interface APIs, meaning that an application using these interfaces is
    only guaranteed to work with the Qt version it was developed against.
    """

    class QSGOpenGLTexture(PyQt6.sip.simplewrapper):
        @staticmethod
        def fromNative(
            textureId: int,
            window: QQuickWindow,
            size: QtCore.QSize,
            options: QQuickWindow.CreateTextureOption = ...,
        ) -> QSGTexture:
            ...

        def nativeTexture(self) -> int:
            ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QGraphicsSimpleTextItem(QAbstractGraphicsShapeItem):
    """
    https://doc.qt.io/qt-6/qgraphicssimpletextitem.html

    **Detailed Description**

    To set the item's text, you can either pass a **QString**  to
    QGraphicsSimpleTextItem's constructor, or call **setText** () to change the
    text later. To set the text fill color, call **setBrush** ().

    The simple text item can have both a fill and an outline; **setBrush** ()
    will set the text fill (i.e., text color), and **setPen** () sets the pen
    that will be used to draw the text outline. (The latter can be slow,
    especially for complex pens, and items with long text content.) If all you
    want is to draw a simple line of text, you should call **setBrush** () only,
    and leave the pen unset; QGraphicsSimpleTextItem's pen is by default
    **Qt::NoPen** .

    QGraphicsSimpleTextItem uses the text's formatted size and the associated
    font to provide a reasonable implementation of **boundingRect** (),
    **shape** (), and **contains** (). You can set the font by calling
    **setFont** ().

    QGraphicsSimpleText does not display rich text; instead, you can use
    **QGraphicsTextItem** , which provides full text control capabilities.

    ![](images/graphicsview-simpletextitem.png)

    **See also** **QGraphicsTextItem** , **QGraphicsPathItem** ,
    **QGraphicsRectItem** , **QGraphicsEllipseItem** , **QGraphicsPixmapItem** ,
    **QGraphicsPolygonItem** , **QGraphicsLineItem** , and **Graphics View
    Framework** .
    """

    @typing.overload
    def __init__(self, parent: typing.Optional[QGraphicsItem] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicssimpletextitem.html#QGraphicsSimpleTextI
        tem

        **QGraphicsSimpleTextItem::QGraphicsSimpleTextItem(QGraphicsItem *
        parent = nullptr)**

        Constructs a QGraphicsSimpleTextItem.

        **parent** is passed to **QGraphicsItem** 's constructor.

        **See also** **QGraphicsScene::addItem** ().
        """
        ...

    @typing.overload
    def __init__(self, text: str, parent: typing.Optional[QGraphicsItem] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicssimpletextitem.html#QGraphicsSimpleTextI
        tem-1

        **QGraphicsSimpleTextItem::QGraphicsSimpleTextItem(const QString & text
        , QGraphicsItem * parent = nullptr)**

        Constructs a QGraphicsSimpleTextItem, using **text** as the default
        plain text.

        **parent** is passed to **QGraphicsItem** 's constructor.

        **See also** **QGraphicsScene::addItem** ().
        """
        ...

    def type(self) -> int:
        """
        https://doc.qt.io/qt-6/qgraphicssimpletextitem.html#type

        **[override virtual] int QGraphicsSimpleTextItem::type() const**

        Reimplements: **QGraphicsItem::type() const** .
        """
        ...

    def opaqueArea(self) -> QtGui.QPainterPath:
        """
        https://doc.qt.io/qt-6/qgraphicssimpletextitem.html#opaqueArea

        **[override virtual] QPainterPath QGraphicsSimpleTextItem::opaqueArea()
        const**

        Reimplements: **QAbstractGraphicsShapeItem::opaqueArea() const** .
        """
        ...

    def isObscuredBy(self, item: QGraphicsItem) -> bool:
        """
        https://doc.qt.io/qt-6/qgraphicssimpletextitem.html#isObscuredBy

        **[override virtual] bool QGraphicsSimpleTextItem::isObscuredBy(const
        QGraphicsItem * item ) const**

        Reimplements: **QAbstractGraphicsShapeItem::isObscuredBy(const
        QGraphicsItem *item) const** .
        """
        ...

    def paint(
        self,
        painter: QtGui.QPainter,
        option: "QStyleOptionGraphicsItem",
        widget: QWidget,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicssimpletextitem.html#paint

        **[override virtual] void QGraphicsSimpleTextItem::paint(QPainter *
        painter , const QStyleOptionGraphicsItem * option , QWidget * widget )**

        Reimplements: **QGraphicsItem::paint** (QPainter *painter, const
        QStyleOptionGraphicsItem *option, QWidget *widget).
        """
        ...

    def contains(self, point: QtCore.QPointF) -> bool:
        """
        https://doc.qt.io/qt-6/qgraphicssimpletextitem.html#contains

        **[override virtual] bool QGraphicsSimpleTextItem::contains(const
        QPointF & point ) const**

        Reimplements: **QGraphicsItem::contains(const QPointF &point) const** .
        """
        ...

    def shape(self) -> QtGui.QPainterPath:
        """
        https://doc.qt.io/qt-6/qgraphicssimpletextitem.html#shape

        **[override virtual] QPainterPath QGraphicsSimpleTextItem::shape()
        const**

        Reimplements: **QGraphicsItem::shape() const** .
        """
        ...

    def boundingRect(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qgraphicssimpletextitem.html#boundingRect

        **[override virtual] QRectF QGraphicsSimpleTextItem::boundingRect()
        const**

        Reimplements: **QGraphicsItem::boundingRect() const** .
        """
        ...

    def font(self) -> QtGui.QFont:
        """
        https://doc.qt.io/qt-6/qgraphicssimpletextitem.html#font

        **QFont QGraphicsSimpleTextItem::font() const**

        Returns the font that is used to draw the item's text.

        **See also** **setFont** ().
        """
        ...

    def setFont(self, font: QtGui.QFont) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicssimpletextitem.html#setFont

        **void QGraphicsSimpleTextItem::setFont(const QFont & font )**

        Sets the font that is used to draw the item's text to **font**.

        **See also** **font** ().
        """
        ...

    def text(self) -> str:
        """
        https://doc.qt.io/qt-6/qgraphicssimpletextitem.html#text

        **QString QGraphicsSimpleTextItem::text() const**

        Returns the item's text.

        **See also** **setText** ().
        """
        ...

    def setText(self, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicssimpletextitem.html#setText

        **void QGraphicsSimpleTextItem::setText(const QString & text )**

        Sets the item's text to **text**. The text will be displayed as plain
        text. Newline characters ('\\n') as well as characters of type
        **QChar::LineSeparator**  will cause item to break the text into
        multiple lines.

        **See also** **text** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
import datetime
from PyQt6.QtNetwork import *
import enum


class QHstsPolicy(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qhstspolicy.html

    **Detailed Description**

    HSTS policy defines a period of time during which **QNetworkAccessManager**
    should only access a host in a secure fashion. HSTS policy is defined by
    RFC6797.

    You can set expiry time and host name for this policy, and control whether
    it applies to subdomains, either in the constructor or by calling
    **setExpiry** (), **setHost** () and setIncludesSubdomains().

    **See also** **QNetworkAccessManager::setStrictTransportSecurityEnabled**
    ().
    """

    class PolicyFlag(enum.Flag):
        IncludeSubDomains: QHstsPolicy = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qhstspolicy.html#QHstsPolicy

        **QHstsPolicy::QHstsPolicy()**

        Constructs an invalid (expired) policy with empty host name and
        subdomains not included.
        """
        ...

    @typing.overload
    def __init__(
        self,
        expiry: typing.Union[QtCore.QDateTime, datetime.datetime],
        flags: "QHstsPolicy.PolicyFlag",
        host: str,
        mode: QtCore.QUrl.ParsingMode = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qhstspolicy.html#QHstsPolicy-1

        **QHstsPolicy::QHstsPolicy(const QDateTime & expiry ,
        QHstsPolicy::PolicyFlags flags , const QString & host ,
        QUrl::ParsingMode mode = QUrl::DecodedMode)**

        Constructs QHstsPolicy with **expiry** (in UTC); **flags** is a value
        indicating whether this policy must also include subdomains, **host**
        data is interpreted according to **mode**.

        **See also** **QUrl::setHost** (), **QUrl::ParsingMode** , and
        **QHstsPolicy::PolicyFlag** .
        """
        ...

    @typing.overload
    def __init__(self, rhs: "QHstsPolicy") -> None:
        """
        https://doc.qt.io/qt-6/qhstspolicy.html#QHstsPolicy-2

        **QHstsPolicy::QHstsPolicy(const QHstsPolicy & other )**

        Creates a copy of **other** object.
        """
        ...

    def isExpired(self) -> bool:
        """
        https://doc.qt.io/qt-6/qhstspolicy.html#isExpired

        **bool QHstsPolicy::isExpired() const**

        Return `true` if this policy has a valid expiration date and this date
        is greater than QDateTime::currentGetDateTimeUtc().

        **See also** **setExpiry** () and **expiry** ().
        """
        ...

    def includesSubDomains(self) -> bool:
        """
        https://doc.qt.io/qt-6/qhstspolicy.html#includesSubDomains

        **bool QHstsPolicy::includesSubDomains() const**

        Returns `true` if this policy also includes subdomains.

        **See also** **setIncludesSubDomains** ().
        """
        ...

    def setIncludesSubDomains(self, include: bool) -> None:
        """
        https://doc.qt.io/qt-6/qhstspolicy.html#setIncludesSubDomains

        **void QHstsPolicy::setIncludesSubDomains(bool include )**

        Sets whether subdomains are included for this policy to **include**.

        **See also** **includesSubDomains** ().
        """
        ...

    def expiry(self) -> QtCore.QDateTime:
        """
        https://doc.qt.io/qt-6/qhstspolicy.html#expiry

        **QDateTime QHstsPolicy::expiry() const**

        Returns the expiration date for the policy (in UTC).

        **See also** **setExpiry** ().
        """
        ...

    def setExpiry(
        self, expiry: typing.Union[QtCore.QDateTime, datetime.datetime]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qhstspolicy.html#setExpiry

        **void QHstsPolicy::setExpiry(const QDateTime & expiry )**

        Sets the expiration date for the policy (in UTC) to **expiry**.

        **See also** **expiry** ().
        """
        ...

    def host(self, options: QtCore.QUrl.ComponentFormattingOption = ...) -> str:
        """
        https://doc.qt.io/qt-6/qhstspolicy.html#host

        **QString QHstsPolicy::host(QUrl::ComponentFormattingOptions options =
        QUrl::FullyDecoded) const**

        Returns a host for a given policy, formatted according to **options**.

        **See also** **setHost** (), **QUrl::host** (), and
        **QUrl::ComponentFormattingOptions** .
        """
        ...

    def setHost(self, host: str, mode: QtCore.QUrl.ParsingMode = ...) -> None:
        """
        https://doc.qt.io/qt-6/qhstspolicy.html#setHost

        **void QHstsPolicy::setHost(const QString & host , QUrl::ParsingMode
        mode = QUrl::DecodedMode)**

        Sets a host, **host** data is interpreted according to **mode**
        parameter.

        **See also** **host** (), **QUrl::setHost** (), and
        **QUrl::ParsingMode** .
        """
        ...

    def swap(self, other: "QHstsPolicy") -> None:
        """
        https://doc.qt.io/qt-6/qhstspolicy.html#swap

        **void QHstsPolicy::swap(QHstsPolicy & other )**

        Swaps this policy with the **other** policy.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QDragEnterEvent(QDragMoveEvent):
    """
    https://doc.qt.io/qt-6/qdragenterevent.html

    **Detailed Description**

    A widget must accept this event in order to receive the **drag move events**
    that are sent while the drag and drop action is in progress. The drag enter
    event is always immediately followed by a drag move event.

    QDragEnterEvent inherits most of its functionality from **QDragMoveEvent** ,
    which in turn inherits most of its functionality from **QDropEvent** .

    **See also** **QDragLeaveEvent** , **QDragMoveEvent** , and **QDropEvent** .
    """

    def __init__(
        self,
        pos: QtCore.QPoint,
        actions: QtCore.Qt.DropAction,
        data: QtCore.QMimeData,
        buttons: QtCore.Qt.MouseButton,
        modifiers: QtCore.Qt.KeyboardModifier,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdragenterevent.html#QDragEnterEvent-2

        **QDragEnterEvent::QDragEnterEvent(const QPoint & point ,
        Qt::DropActions actions , const QMimeData * data , Qt::MouseButtons
        buttons , Qt::KeyboardModifiers modifiers )**

        Constructs a QDragEnterEvent that represents a drag entering a widget at
        the given **point** with mouse and keyboard states specified by
        **buttons** and **modifiers**.

        The drag data is passed as MIME-encoded information in **data** , and
        the specified **actions** describe the possible types of drag and drop
        operation that can be performed.

        **Warning:** Do not create a QDragEnterEvent yourself since these
        objects rely on Qt's internal state.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QDBusVariant(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qdbusvariant.html

    **Detailed Description**

    A D-Bus function that takes an integer, a D-Bus variant and a string as
    parameters can be called with the following argument list (see
    **QDBusMessage::setArguments** ()):

    **QList** <**QVariant** > arguments;
            arguments << **QVariant** (42)
    << **QVariant** ::fromValue(**QDBusVariant** (43)) << **QVariant**
    ("hello");
            myDBusMessage.setArguments(arguments);

    When a D-Bus function returns a D-Bus variant, it can be retrieved as
    follows:

    // call a D-Bus function that returns a D-Bus variant
            **QVariant**
    v = callMyDBusFunction();
            // retrieve the D-Bus variant
    **QDBusVariant**  dbusVariant = qvariant_cast<**QDBusVariant** >(v);
    // retrieve the actual value stored in the D-Bus variant
    **QVariant**  result = dbusVariant.variant();

    The **QVariant**  within a QDBusVariant is required to distinguish between a
    normal D-Bus value and a value within a D-Bus variant.

    **See also** **The Qt D-Bus Type System** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qdbusvariant.html#QDBusVariant

        **QDBusVariant::QDBusVariant()**

        Constructs a new D-Bus variant.
        """
        ...

    @typing.overload
    def __init__(self, dBusVariant: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qdbusvariant.html#QDBusVariant-1

        **QDBusVariant::QDBusVariant(const QVariant & variant )**

        Constructs a new D-Bus variant from the given Qt **variant**.

        **See also** **setVariant** ().
        """
        ...

    @typing.overload
    def __init__(self, a0: "QDBusVariant") -> None:
        """
        https://doc.qt.io/qt-6/qdbusvariant.html#QDBusVariant

        **QDBusVariant::QDBusVariant()**

        Constructs a new D-Bus variant.
        """
        ...

    def swap(self, other: "QDBusVariant") -> None:
        """
        https://doc.qt.io/qt-6/qdbusvariant.html#swap

        **void QDBusVariant::swap(QDBusVariant & other )**

        Swaps this **QDBusVariant**  instance with **other**.
        """
        ...

    def setVariant(self, dBusVariant: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qdbusvariant.html#setVariant

        **void QDBusVariant::setVariant(const QVariant & variant )**

        Assigns the value of the given Qt **variant** to this D-Bus variant.

        **See also** **variant** ().
        """
        ...

    def variant(self) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qdbusvariant.html#variant

        **QVariant QDBusVariant::variant() const**

        Returns this D-Bus variant as a **QVariant**  object.

        **See also** **setVariant** ().
        """
        ...
